/* This program file includes GeoLite data created by MaxMind,
available from http://www.maxmind.com. The GeoLite databases are
distributed under the Creative Commons Attribution-ShareAlike 3.0
Unported License. */

#include "ip-tools.h"
int n_china_ips = 2787;
ip_block_t china_ips[2787] = {
{0x1000100,0x10003FF},
{0x1000800,0x1000FFF},
{0x1002000,0x1003FFF},
{0x1010000,0x10100FF},
{0x1010200,0x1013FFF},
{0x1020000,0x10202FF},
{0x1020400,0x1027FFF},
{0x1030000,0x103FFFF},
{0x1040100,0x1047FFF},
{0x1080000,0x108FFFF},
{0x10A0000,0x10A09FF},
{0x10A0B00,0x10A7FFF},
{0x10C0000,0x10FFFFF},
{0x1180000,0x11FFFFF},
{0x12D0000,0x12DFFFF},
{0x1300000,0x133FFFF},
{0x1380000,0x13FFFFF},
{0x1440000,0x147FFFF},
{0x1500000,0x15FFFFF},
{0x1740000,0x177FFFF},
{0x1B40000,0x1B9FFFF},
{0x1BC0000,0x1C7FFFF},
{0x1CA0000,0x1CFFFFF},
{0x50A4628,0x50A462B},
{0x50A4650,0x50A4657},
{0x50A47E9,0x50A47E9},
{0x50A4850,0x50A485F},
{0x50A4A28,0x50A4A9F},
{0x50A4AC0,0x50A4ADF},
{0x50A4BE0,0x50A4BEF},
{0x50A4FF0,0x50A4FF7},
{0x50A52A8,0x50A52AF},
{0x50A5468,0x50A546F},
{0x50A5508,0x50A550B},
{0x50A5550,0x50A5557},
{0x50A5560,0x50A5567},
{0x50A5630,0x50A5637},
{0x50A5648,0x50A564B},
{0x50A56A0,0x50A56A7},
{0x50A5702,0x50A5702},
{0x50A5760,0x50A5767},
{0x50A5780,0x50A5787},
{0x50A57C0,0x50A57C1},
{0x50A57D6,0x50A57D7},
{0x50A57F4,0x50A57F6},
{0x50A57FC,0x50A57FD},
{0x50A58F0,0x50A58FF},
{0x50A5AE8,0x50A5AEF},
{0x50A6148,0x50A614B},
{0x50A61A0,0x50A61A7},
{0x50A68D8,0x50A68DF},
{0x50A6B50,0x50A6B57},
{0x50A6D10,0x50A6D1F},
{0x50A6D78,0x50A6D7F},
{0x50A6DD0,0x50A6DD7},
{0x50A6EE0,0x50A6EEF},
{0x50A6F08,0x50A6F0F},
{0x50A6F38,0x50A6F3F},
{0x50A7218,0x50A721B},
{0x50A729F,0x50A729F},
{0x50A7428,0x50A7437},
{0x50A7460,0x50A746F},
{0x50A7770,0x50A7777},
{0x50A78E8,0x50A78EF},
{0x50A7A08,0x50A7A0F},
{0x50A7A3E,0x50A7A3E},
{0x50A7AF0,0x50A7AF7},
{0x53F1900,0x53F19FF},
{0x5990044,0x5990047},
{0x59900A0,0x59900AF},
{0x5990450,0x5990457},
{0x59904F7,0x59904F7},
{0x59907FE,0x59907FE},
{0x5990AB8,0x5990ABF},
{0x5990B30,0x5990B37},
{0x5990F88,0x5990F8F},
{0x5991158,0x599115F},
{0x59912A8,0x59912AB},
{0x5991388,0x599138F},
{0x5991418,0x599141B},
{0x5991490,0x5991497},
{0x59914F8,0x59914FF},
{0x5C6FBA8,0x5C6FBAF},
{0x5C7AE10,0x5C7AE27},
{0x5C7AF08,0x5C7AF1F},
{0x5C7AF70,0x5C7AF77},
{0x5E03600,0x5E036FF},
{0x5E13600,0x5E136FF},
{0xE000000,0xE0007FF},
{0xE000C00,0xE000FFF},
{0xE010000,0xE0103FF},
{0xE100000,0xE1FFFFF},
{0xE668000,0xE6683FF},
{0xE669C00,0xE669FFF},
{0xE670000,0xE7FFFFF},
{0xE820000,0xE83FFFF},
{0xE860000,0xE87FFFF},
{0xE900000,0xE9FFFFF},
{0xEC03C00,0xEC03FFF},
{0xEC04C00,0xEC04FFF},
{0xEC40000,0xEC5FFFF},
{0xECC0000,0xECDFFFF},
{0xED00000,0xEDFFFFF},
{0xFD3E900,0xFD3E9FF},
{0x1B080000,0x1B1FFFFF},
{0x1B22E800,0x1B22EFFF},
{0x1B240000,0x1B2FFFFF},
{0x1B322800,0x1B322FFF},
{0x1B328000,0x1B32FFFF},
{0x1B364800,0x1B364FFF},
{0x1B369800,0x1B369FFF},
{0x1B36C000,0x1B36FFFF},
{0x1B62D000,0x1B62FFFF},
{0x1B638000,0x1B63FFFF},
{0x1B670000,0x1B67FFFF},
{0x1B6A8000,0x1B6ABFFF},
{0x1B6ACC00,0x1B6ACFFF},
{0x1B6D2000,0x1B6D3FFF},
{0x1B700000,0x1B703FFF},
{0x1B705000,0x1B705FFF},
{0x1B718000,0x1B71BFFF},
{0x1B730000,0x1B737FFF},
{0x1B742C00,0x1B742FFF},
{0x1B794800,0x1B794FFF},
{0x1B797800,0x1B797FFF},
{0x1B800000,0x1B81FFFF},
{0x1B83DC00,0x1B83DFFF},
{0x1B900000,0x1B90FFFF},
{0x1B940000,0x1B9FFFFF},
{0x1BB80000,0x1BE3FFFF},
{0x1FC90004,0x1FC90007},
{0x1FC90400,0x1FC904DF},
{0x1FD68C80,0x1FD68CBF},
{0x1FD69300,0x1FD693FF},
{0x1FD69A00,0x1FD69AFF},
{0x24000000,0x240003FF},
{0x24000800,0x2401FFFF},
{0x24040000,0x2407FFFF},
{0x24100000,0x24251FFF},
{0x24252400,0x242525FF},
{0x24252700,0x24253FFF},
{0x24280000,0x2433FFFF},
{0x24380000,0x243FFFFF},
{0x24600000,0x24DFFFFF},
{0x24F80000,0x24FBFFFF},
{0x24FE0000,0x24FEFFFF},
{0x253A4340,0x253A4347},
{0x253A46A0,0x253A46BF},
{0x253A46E8,0x253A46EB},
{0x253A4A70,0x253A4A77},
{0x253A4B30,0x253A4B37},
{0x253A4D48,0x253A4D4F},
{0x253A5426,0x253A5426},
{0x253A54F0,0x253A54F7},
{0x253A5780,0x253A5787},
{0x253A5B44,0x253A5B47},
{0x253A5B58,0x253A5B5F},
{0x253A5D28,0x253A5D37},
{0x253A5E78,0x253A5E7F},
{0x253A5E81,0x253A5E81},
{0x253A5EC0,0x253A5EC7},
{0x253A5FF0,0x253A5FF7},
{0x253A61EC,0x253A61EF},
{0x253A6478,0x253A647F},
{0x253A6A0C,0x253A6A0F},
{0x253A6A20,0x253A6A37},
{0x253A6A68,0x253A6A6B},
{0x253A6AA0,0x253A6ABF},
{0x253A6AE0,0x253A6AEB},
{0x253A6E30,0x253A6E37},
{0x253A7048,0x253A704F},
{0x253A7440,0x253A7447},
{0x253A7780,0x253A779F},
{0x253A7980,0x253A7987},
{0x253A7E48,0x253A7E4F},
{0x253A7E80,0x253A7E87},
{0x253A7FA0,0x253A7FA7},
{0x25DE3600,0x25DE36FF},
{0x25DF2D00,0x25DF2DFF},
{0x27000000,0x270000FF},
{0x27000200,0x2700FFFF},
{0x27400000,0x275FFFFF},
{0x27800000,0x27BFFFFF},
{0x2A000000,0x2A0003FF},
{0x2A000800,0x2A001BFF},
{0x2A002000,0x2A003FFF},
{0x2A008000,0x2A013BFF},
{0x2A018000,0x2A01FFFF},
{0x2A040000,0x2A07FFFF},
{0x2A300000,0x2A3BFFFF},
{0x2A3E0000,0x2A3EAFFF},
{0x2A3EB400,0x2A3EBFFF},
{0x2A3F0000,0x2A3FFFFF},
{0x2A500000,0x2A51FFFF},
{0x2A534000,0x2A5353FF},
{0x2A535800,0x2A5FFFFF},
{0x2A604000,0x2A6067FF},
{0x2A606C00,0x2A61FFFF},
{0x2A630000,0x2A6373FF},
{0x2A637800,0x2A637FFF},
{0x2A640000,0x2A67FFFF},
{0x2A780000,0x2A7B1FFF},
{0x2A7B2400,0x2A7BFFFF},
{0x2A800000,0x2A8FFFFF},
{0x2A9C0000,0x2A9C1FFF},
{0x2A9C2400,0x2ABB7BFF},
{0x2ABB8000,0x2ABBFFFF},
{0x2AC00000,0x2AC7FFFF},
{0x2AC90000,0x2AC97FFF},
{0x2ACA0000,0x2AF0FFFF},
{0x2AF20000,0x2AFFFFFF},
{0x2E24C26F,0x2E24C278},
{0x2E88BE00,0x2E88BEFF},
{0x2EF81800,0x2EF819FF},
{0x31040000,0x3107FFFF},
{0x31330000,0x3137FFFF},
{0x31400000,0x315FFFFF},
{0x31700000,0x317BFFFF},
{0x31800000,0x318000FF},
{0x31800200,0x318003FF},
{0x318C0000,0x318DFFFF},
{0x31980000,0x319BFFFF},
{0x31D00000,0x31D3FFFF},
{0x31DC0000,0x31DFFFFF},
{0x31E80000,0x31EBFFFF},
{0x31EF0000,0x31EF3FFF},
{0x31EFC000,0x31EFFFFF},
{0x31F6E000,0x31F6FFFF},
{0x3202FC40,0x3202FC47},
{0x32768000,0x327680FF},
{0x3A0E0000,0x3A19FFFF},
{0x3A1E0000,0x3A3FFFFF},
{0x3A41E800,0x3A41EFFF},
{0x3A420000,0x3A43FFFF},
{0x3A448000,0x3A44FFFF},
{0x3A520000,0x3A527FFF},
{0x3A530000,0x3A53FFFF},
{0x3A574000,0x3A577FFF},
{0x3A638000,0x3A65FFFF},
{0x3A740000,0x3A77FFFF},
{0x3A800000,0x3A87FFFF},
{0x3A900000,0x3A90FFFF},
{0x3A9A0000,0x3A9BFFFF},
{0x3AC00000,0x3ADFFFFF},
{0x3AF00000,0x3AFFFFFF},
{0x3B200000,0x3B53FFFF},
{0x3B6B0000,0x3B6FFFFF},
{0x3B970000,0x3B977FFF},
{0x3B9B0000,0x3B9BFFFF},
{0x3BAC0000,0x3BAFFFFF},
{0x3BBF0000,0x3BBF7FFF},
{0x3BBFF000,0x3C1FFFFF},
{0x3C370000,0x3C37FFFF},
{0x3C3F0000,0x3C3FFFFF},
{0x3CA00000,0x3CBFFFFF},
{0x3CC20000,0x3CC3FFFF},
{0x3CC80000,0x3CDFFFFF},
{0x3CE80000,0x3CE9FFFF},
{0x3CEB0000,0x3CEBFFFF},
{0x3CF58000,0x3CF5FFFF},
{0x3CF70000,0x3CF7FFFF},
{0x3CFC0000,0x3CFCFFFF},
{0x3CFD8000,0x3CFDFFFF},
{0x3CFF0000,0x3CFFFFFF},
{0x3D045000,0x3D045FFF},
{0x3D04B000,0x3D04BFFF},
{0x3D08A000,0x3D08AFFF},
{0x3D1C0000,0x3D1C7FFF},
{0x3D1CC300,0x3D1CC4FF},
{0x3D1D8000,0x3D1DFFFF},
{0x3D2D8000,0x3D2DBFFF},
{0x3D2DE000,0x3D2DEFFF},
{0x3D2F8000,0x3D2FBFFF},
{0x3D300000,0x3D37FFFF},
{0x3D57C000,0x3D57FFFF},
{0x3D800000,0x3DBFFFFF},
{0x3DE80000,0x3DEDFFFF},
{0x3DF00000,0x3DF3FFFF},
{0x3FA28E00,0x3FA28EFF},
{0x3FA764C0,0x3FA764CF},
{0x402572A0,0x402572BF},
{0x403E9708,0x403E970F},
{0x403ECEE0,0x403ECEFF},
{0x403EFF00,0x403EFFFF},
{0x404004F3,0x404004F6},
{0x40479760,0x4047977F},
{0x4047AC00,0x4047ACFF},
{0x404B0EC0,0x404B0EDF},
{0x404EA200,0x404EA2FF},
{0x404EA560,0x404EA56F},
{0x407F6700,0x407F6707},
{0x40E07CE1,0x40E07CEE},
{0x41138670,0x41138677},
{0x41138700,0x411387FF},
{0x41139800,0x411398FF},
{0x4113BC00,0x4113BCFF},
{0x41314840,0x4131487F},
{0x413F3880,0x413F389F},
{0x413F59CC,0x413F59CF},
{0x4164E500,0x4164E567},
{0x4164E580,0x4164E59F},
{0x4164E5C0,0x4164E5CF},
{0x41FF2400,0x41FF24FF},
{0x41FF2600,0x41FF27FF},
{0x41FF2900,0x41FF297F},
{0x41FF2A00,0x41FF2A7F},
{0x4225D8C0,0x4225D8DF},
{0x42365000,0x423653FF},
{0x42A08200,0x42A082FF},
{0x42A0A200,0x42A0A2FF},
{0x42A57E00,0x42A57E0F},
{0x42C9BC00,0x42C9BCFF},
{0x43166520,0x43166527},
{0x431666A8,0x431666AF},
{0x432BE2E8,0x432BE2EF},
{0x432BE6C8,0x432BE6CF},
{0x43DE9E1F,0x43DE9E5E},
{0x444465C8,0x444465CF},
{0x444465E0,0x444465E7},
{0x44446878,0x4444687F},
{0x44446988,0x44446997},
{0x444469A0,0x444469CF},
{0x444469D8,0x444469DF},
{0x44446D80,0x44446D8F},
{0x44446DB0,0x44446DB7},
{0x4447FA60,0x4447FA7F},
{0x44A87080,0x44A870BF},
{0x44AB6600,0x44AB67FF},
{0x454021A0,0x454021A0},
{0x454021A3,0x454021A3},
{0x454021A6,0x454021A6},
{0x454021B1,0x454021B1},
{0x454022D9,0x454022D9},
{0x455A6388,0x455A638F},
{0x45C519BC,0x45C519BF},
{0x48017930,0x4801793F},
{0x480AA840,0x480AA847},
{0x480AACC0,0x480AACCF},
{0x480AADC0,0x480AADC7},
{0x480D5188,0x480D5197},
{0x480D5238,0x480D523F},
{0x480D5248,0x480D524F},
{0x480D5258,0x480D525F},
{0x480D5278,0x480D527F},
{0x480D52C8,0x480D52CF},
{0x481C6A08,0x481C6A0F},
{0x481C6A40,0x481C6A5F},
{0x481C7500,0x481C75FF},
{0x48345DE0,0x48345DFF},
{0x48345EE0,0x48345EE7},
{0x48345EF0,0x48345EF7},
{0x48A3FC00,0x48A3FCFF},
{0x4A5B1000,0x4A5B1007},
{0x4A5B1020,0x4A5B102F},
{0x4A5B1038,0x4A5B1047},
{0x4A5B1060,0x4A5B1067},
{0x4A5B10A0,0x4A5B10BF},
{0x4A5B10E0,0x4A5B10E7},
{0x4A5B10F0,0x4A5B10F7},
{0x4A5B1100,0x4A5B113F},
{0x4A5B1190,0x4A5B1197},
{0x4A5B11A0,0x4A5B11BF},
{0x4A5B11E8,0x4A5B11EF},
{0x4A5B1210,0x4A5B1217},
{0x4A5B1220,0x4A5B123F},
{0x4A5B1280,0x4A5B128F},
{0x4A5B1298,0x4A5B12AF},
{0x4A5B12B8,0x4A5B12BF},
{0x4A5B12C8,0x4A5B12D7},
{0x4A5B12F8,0x4A5B12FF},
{0x4A5B13C0,0x4A5B13DF},
{0x4A5B1458,0x4A5B145F},
{0x4A5B1488,0x4A5B149F},
{0x4A5B14C8,0x4A5B14D7},
{0x4A5B14E8,0x4A5B14EF},
{0x4A5B1700,0x4A5B1707},
{0x4A5B1720,0x4A5B173F},
{0x4A5B1760,0x4A5B176F},
{0x4A5B1778,0x4A5B17AF},
{0x4A5B17B8,0x4A5B17DF},
{0x4A5B1D00,0x4A5B1D07},
{0x4A5B1D30,0x4A5B1D4F},
{0x4A5B1E00,0x4A5B1E0F},
{0x4A5B1E18,0x4A5B1E1F},
{0x4A5B1E30,0x4A5B1E3F},
{0x4A5B1E48,0x4A5B1E67},
{0x4A5B1EC0,0x4A5B1EC7},
{0x4A5B1ED0,0x4A5B1EE7},
{0x4A5B1EF0,0x4A5B1F1F},
{0x4A5B1F28,0x4A5B1F2F},
{0x4A5B1F38,0x4A5B1FFF},
{0x4A7F2660,0x4A7F267F},
{0x4B4BEC00,0x4B4BEC07},
{0x4B4BEC28,0x4B4BEC2F},
{0x4C48A638,0x4C48A63F},
{0x4C48A8E8,0x4C48A8EF},
{0x4C4AAEA0,0x4C4AAEA7},
{0x4C4AAF20,0x4C4AAF2F},
{0x4E18C950,0x4E18C95F},
{0x4E18CA28,0x4E18CA2F},
{0x4E18CB28,0x4E18CB2F},
{0x4E18CE28,0x4E18CE2F},
{0x515C7DF0,0x515C7DFF},
{0x515F96A0,0x515F96BF},
{0x515F9900,0x515F993F},
{0x515F9AC0,0x515F9B1F},
{0x54167F10,0x54167F17},
{0x54C8C800,0x54C8C87F},
{0x54C926C0,0x54C926FF},
{0x55191BD1,0x55191BD1},
{0x5519FE1D,0x5519FE1D},
{0x5519FE21,0x5519FE22},
{0x57FECE00,0x57FECFFF},
{0x5BBEAD00,0x5BBEADFF},
{0x5BC4E800,0x5BC4EBFF},
{0x5BEA2400,0x5BEA24FF},
{0x5F82C500,0x5F82C57F},
{0x5F82C600,0x5F82C67F},
{0x5F8F4828,0x5F8F482F},
{0x627E8BC8,0x627E8BCF},
{0x627EDD00,0x627EDEFF},
{0x642AE200,0x642AE3DF},
{0x642AE400,0x642AE45F},
{0x642AE470,0x642AE477},
{0x642AE490,0x642AE49F},
{0x642AE4B0,0x642AE4BF},
{0x642AE500,0x642AE55F},
{0x642AE580,0x642AE77F},
{0x642AE7A0,0x642AE83F},
{0x642AE860,0x642AEC87},
{0x642AEC90,0x642AEC9F},
{0x642AECB0,0x642AED97},
{0x642AEDC0,0x642AEFBF},
{0x65000000,0x650003FF},
{0x65010000,0x650103FF},
{0x6502AC00,0x6502AFFF},
{0x65040000,0x6507FFFF},
{0x65100000,0x6531FFFF},
{0x65323800,0x65323BFF},
{0x65340000,0x6534FFFF},
{0x65356400,0x653567FF},
{0x65360000,0x6536FFFF},
{0x6537E000,0x6537E7FF},
{0x65400000,0x654E03FF},
{0x654E2000,0x654E3FFF},
{0x65500000,0x65600BFF},
{0x65601000,0x65601FFF},
{0x65608000,0x6560FFFF},
{0x65636000,0x65637FFF},
{0x65654000,0x65655FFF},
{0x65656400,0x656564FF},
{0x65656600,0x65657FFF},
{0x65664000,0x65665FFF},
{0x65666400,0x656666FF},
{0x65666800,0x65667FFF},
{0x65680000,0x656BFFFF},
{0x656E4000,0x656E6FFF},
{0x656E7400,0x656E7FFF},
{0x65780000,0x657EFFFF},
{0x65800000,0x658003FF},
{0x65800800,0x65803FFF},
{0x65810000,0x6587FFFF},
{0x65900000,0x659FFFFF},
{0x65C00000,0x65C9FFFF},
{0x65CB8000,0x65CBA7FF},
{0x65CBAC00,0x65CBBFFF},
{0x65CC0000,0x65CFFFFF},
{0x65E00000,0x65E9FFFF},
{0x65EA4000,0x65EA47FF},
{0x65EA4C00,0x65EA7FFF},
{0x65EC0000,0x65F9FFFF},
{0x65FB0000,0x65FB03FF},
{0x65FB0800,0x65FEFFFF},
{0x67010800,0x67010BFF},
{0x67011400,0x67011BFF},
{0x67014800,0x67014BFF},
{0x67015800,0x67015BFF},
{0x6701A800,0x6701ABFF},
{0x67026C00,0x67026FFF},
{0x67029C00,0x67029FFF},
{0x6702A400,0x6702A7FF},
{0x6702C800,0x6702D7FF},
{0x67035400,0x67038FFF},
{0x67039400,0x67039FFF},
{0x67043800,0x67043BFF},
{0x6704A800,0x6704ABFF},
{0x6704B800,0x6704BBFF},
{0x67052400,0x670527FF},
{0x67053400,0x67053BFF},
{0x6705FC00,0x6705FFFF},
{0x67064C00,0x67064FFF},
{0x6706DC00,0x6706DFFF},
{0x67070400,0x670707FF},
{0x67071C00,0x67071FFF},
{0x6707D400,0x6707DFFF},
{0x67080400,0x67080BFF},
{0x67082000,0x670823FF},
{0x67083400,0x670837FF},
{0x67086C00,0x67086FFF},
{0x67089C00,0x67089FFF},
{0x6708C800,0x6708CFFF},
{0x6708DC00,0x6708DFFF},
{0x67099800,0x67099BFF},
{0x6709F800,0x670A03FF},
{0x670A1000,0x670A13FF},
{0x670A5400,0x670A57FF},
{0x670A6F00,0x670A6FFF},
{0x670A8C00,0x670A8FFF},
{0x670BB400,0x670BB7FF},
{0x670C2000,0x670C23FF},
{0x670C4400,0x670C47FF},
{0x670C8800,0x670C8BFF},
{0x670CB800,0x670CBBFF},
{0x670CE800,0x670CEBFF},
{0x670D7C00,0x670D7FFF},
{0x670D9000,0x670D93FF},
{0x670DC400,0x670DC7FF},
{0x670DF400,0x670DF7FF},
{0x670E5400,0x670E57FF},
{0x670E8400,0x670E8BFF},
{0x670E9C00,0x670E9FFF},
{0x670EF000,0x670EF3FF},
{0x670F0400,0x670F0BFF},
{0x670F1000,0x670F13FF},
{0x670F6000,0x670F63FF},
{0x670FC800,0x670FCBFF},
{0x67103400,0x671037FF},
{0x67105000,0x67105BFF},
{0x67106C00,0x67106FFF},
{0x67107C00,0x67107FFF},
{0x67112800,0x67112BFF},
{0x67117800,0x67117BFF},
{0x6711A000,0x6711A3FF},
{0x67140C00,0x67140FFF},
{0x67142000,0x671423FF},
{0x67147000,0x671473FF},
{0x67148000,0x671483FF},
{0x6714A000,0x6714A3FF},
{0x6714F800,0x6714FBFF},
{0x67157000,0x671577FF},
{0x67158800,0x67158FFF},
{0x6715B000,0x6715B3FF},
{0x6715D000,0x6715D3FF},
{0x6715F000,0x6715F3FF},
{0x67160000,0x67165FFF},
{0x67166400,0x67167FFF},
{0x6716BC00,0x6716BFFF},
{0x6716E400,0x6716E7FF},
{0x6716FC00,0x6716FFFF},
{0x67170800,0x67170BFF},
{0x67173800,0x67173BFF},
{0x6717A000,0x6717A7FF},
{0x6717B000,0x6717B3FF},
{0x6717E400,0x6717E7FF},
{0x671C0400,0x671C0BFF},
{0x671CCC00,0x671CCFFF},
{0x671D1000,0x671D13FF},
{0x671D8000,0x671D8BFF},
{0x671E1400,0x671E17FF},
{0x671E6000,0x671E63FF},
{0x671E9400,0x671E97FF},
{0x671EC800,0x671ECBFF},
{0x671ED800,0x671EDBFF},
{0x671EE400,0x671EEFFF},
{0x671F0000,0x671F03FF},
{0x671F3000,0x671F4BFF},
{0x671F9400,0x671F97FF},
{0x671FA000,0x671FA3FF},
{0x671FA800,0x671FABFF},
{0x671FC800,0x671FCBFF},
{0x67F41000,0x67F413FF},
{0x67F43800,0x67F45BFF},
{0x67F49400,0x67F497FF},
{0x67F4A400,0x67F4A7FF},
{0x67F4E800,0x67F4EBFF},
{0x67F4FC00,0x67F4FFFF},
{0x67F51700,0x67F517FF},
{0x67F53400,0x67F537FF},
{0x67F53C00,0x67F53FFF},
{0x67F55000,0x67F553FF},
{0x67F57C00,0x67F583FF},
{0x67F60800,0x67F60FFF},
{0x67F67800,0x67F67FFF},
{0x67F68400,0x67F687FF},
{0x67F69800,0x67F69FFF},
{0x67F7A800,0x67F7B3FF},
{0x67F7C800,0x67F7CBFF},
{0x67F7D400,0x67F7D7FF},
{0x6A000000,0x6A0000FF},
{0x6A000200,0x6A001FFF},
{0x6A004000,0x6A007FFF},
{0x6A020000,0x6A09FFFF},
{0x6A0B0000,0x6A32FFFF},
{0x6A340000,0x6A3FFFFF},
{0x6A4A0000,0x6A4BFFFF},
{0x6A500000,0x6A5FFFFF},
{0x6A6C0000,0x6A7FFFFF},
{0x6ABB2000,0x6ABB22AF},
{0x6ABB22B1,0x6ABB27FF},
{0x6AE00000,0x6AEFFFFF},
{0x6C3EB940,0x6C3EB97F},
{0x6CAE4260,0x6CAE4277},
{0x6DCD0B20,0x6DCD0B27},
{0x6E060000,0x6E07FFFF},
{0x6E100000,0x6E13FFFF},
{0x6E280000,0x6E2BFFFF},
{0x6E2C9000,0x6E2C9FFF},
{0x6E300000,0x6E30FFFF},
{0x6E330000,0x6E35FFFF},
{0x6E380000,0x6E41FFFF},
{0x6E480000,0x6E49FFFF},
{0x6E4B0000,0x6E4C3FFF},
{0x6E4C9C00,0x6E4C9FFF},
{0x6E4CB800,0x6E4CBBFF},
{0x6E4CC000,0x6E4D7FFF},
{0x6E500000,0x6E5BFFFF},
{0x6E5D2000,0x6E5D3FFF},
{0x6E5E0000,0x6E7FFFFF},
{0x6E980000,0x6E9DFFFF},
{0x6EA53000,0x6EA53FFF},
{0x6EA60000,0x6EA7FFFF},
{0x6EACC000,0x6EAD2FFF},
{0x6EAD4000,0x6EAD7FFF},
{0x6EADC000,0x6EADDFFF},
{0x6EB00000,0x6EDFFFFF},
{0x6EE40000,0x6EE7FFFF},
{0x6EE82000,0x6EE83FFF},
{0x6EEC0000,0x6EEDFFFF},
{0x6EF00000,0x6F3FFFFF},
{0x6F420000,0x6F42FFFF},
{0x6F43C000,0x6F43CFFF},
{0x6F444000,0x6F445FFF},
{0x6F480000,0x6F4FFFFF},
{0x6F550000,0x6F55FFFF},
{0x6F5BC000,0x6F5BDFFF},
{0x6F700000,0x6F75FFFF},
{0x6F76C800,0x6F76CFFF},
{0x6F774000,0x6F779FFF},
{0x6F780000,0x6F7CFFFF},
{0x6F7E0000,0x6FA7FFFF},
{0x6FAA0000,0x6FAAFFFF},
{0x6FAC0000,0x6FB7FFFF},
{0x6FBA0000,0x6FBBFFFF},
{0x6FC00000,0x6FD7FFFF},
{0x6FDD8000,0x6FDEFFFF},
{0x6FDFF000,0x6FDFF3FF},
{0x6FDFF800,0x6FDFFBFF},
{0x6FE00000,0x6FE7FFFF},
{0x6FEB6000,0x6FEB7FFF},
{0x6FEB9C00,0x6FEBBFFF},
{0x70000000,0x7043FFFF},
{0x70490000,0x704BFFFF},
{0x70500000,0x7067FFFF},
{0x706D8000,0x706DFFFF},
{0x706F0000,0x7075FFFF},
{0x707A0000,0x7084FFFF},
{0x70893000,0x708937FF},
{0x70C00000,0x70C3FFFF},
{0x70E00000,0x7109FFFF},
{0x710BC000,0x710BDFFF},
{0x710C0000,0x7112FFFF},
{0x71180000,0x711BFFFF},
{0x711F0000,0x711FFFFF},
{0x712C0000,0x7133FFFF},
{0x7134A000,0x7134BFFF},
{0x71360000,0x713B7FFF},
{0x713BE000,0x713BE3FF},
{0x713E0000,0x7181FFFF},
{0x71826000,0x718277FF},
{0x71840000,0x718FFFFF},
{0x71C20000,0x71C3FFFF},
{0x71C56400,0x71C567FF},
{0x71C80000,0x71CAFFFF},
{0x71CC0000,0x71CFFFFF},
{0x71D06000,0x71D1FFFF},
{0x71D40000,0x71D43FFF},
{0x71D46400,0x71D467FF},
{0x71D4B800,0x71D4BFFF},
{0x71D50000,0x71D57FFF},
{0x71D60000,0x71D7FFFF},
{0x71DA0000,0x71FBFFFF},
{0x721C0000,0x721CFFFF},
{0x72360000,0x7237FFFF},
{0x723C0000,0x7244FFFF},
{0x724F4000,0x724F7FFF},
{0x72500000,0x726BFFFF},
{0x726E0000,0x726E0FFF},
{0x726E4000,0x726E7FFF},
{0x726F0000,0x726F1FFF},
{0x726FA000,0x726FBFFF},
{0x72700000,0x7271EFFF},
{0x72720000,0x7277FFFF},
{0x72840000,0x7284FFFF},
{0x72870000,0x7287FFFF},
{0x728A0000,0x728BFFFF},
{0x728D4000,0x728D47FF},
{0x728D8000,0x728DBFFF},
{0x72C40000,0x72C5FFFF},
{0x72C6F800,0x72C6FFFF},
{0x72D00000,0x72FFFFFF},
{0x73180000,0x731DFFFF},
{0x73200000,0x7323FFFF},
{0x732C0000,0x733FFFFF},
{0x73454000,0x73454FFF},
{0x73540000,0x73543FFF},
{0x7354C000,0x7354DFFF},
{0x7355C000,0x7355FFFF},
{0x73640000,0x736BFFFF},
{0x73780000,0x737BFFFF},
{0x737C1000,0x737C1FFF},
{0x73940000,0x739FFFFF},
{0x73A64000,0x73A65FFF},
{0x73A80000,0x73AFFFFF},
{0x73B40000,0x73B7FFFF},
{0x73BE0000,0x73EFFFFF},
{0x74000800,0x74000FFF},
{0x74001800,0x74001FFF},
{0x74010000,0x740BFFFF},
{0x740D0000,0x740DFFFF},
{0x74100000,0x741FFFFF},
{0x74315900,0x743159FF},
{0x74320000,0x74320FFF},
{0x74340000,0x7439FFFF},
{0x743A8000,0x743A8FFF},
{0x743AD000,0x743ADFFF},
{0x743C0000,0x743FFFFF},
{0x74420000,0x74427FFF},
{0x74450000,0x74467FFF},
{0x744C0000,0x744FFFFF},
{0x74550000,0x7455FFFF},
{0x74599000,0x74599FFF},
{0x745A5000,0x745A5FFF},
{0x745AB800,0x745ABFFF},
{0x745F0000,0x745FFFFF},
{0x74700000,0x7475FFFF},
{0x74800000,0x74C0FFFF},
{0x74C11000,0x74C13FFF},
{0x74C1B000,0x74C1B7FF},
{0x74C20000,0x74C4FFFF},
{0x74C60000,0x74C79FFF},
{0x74CC0000,0x74D3FFFF},
{0x74D4A000,0x74D4AFFF},
{0x74D54000,0x74D5FFFF},
{0x74D62000,0x74D64FFF},
{0x74D68000,0x74DBFFFF},
{0x74E00000,0x74EFFFFF},
{0x74F20000,0x74F9FFFF},
{0x74FB4000,0x74FB7FFF},
{0x74FC0000,0x74FDFFFF},
{0x74FE8000,0x74FEFFFF},
{0x74FF8000,0x74FFFFFF},
{0x75080000,0x750FFFFF},
{0x75150000,0x752DFFFF},
{0x75300000,0x7533FFFF},
{0x75353000,0x75353FFF},
{0x7535B000,0x7535BFFF},
{0x75390000,0x753A7FFF},
{0x753B0000,0x7549FFFF},
{0x754A4000,0x754A5FFF},
{0x754A8000,0x755FFFFF},
{0x75640000,0x7565FFFF},
{0x75671000,0x75671FFF},
{0x75672800,0x75672FFF},
{0x75674800,0x75674FFF},
{0x75678000,0x75678FFF},
{0x7568A800,0x7568AFFF},
{0x756A0000,0x756BFFFF},
{0x75700000,0x7577FFFF},
{0x75784000,0x7579C7FF},
{0x757A8000,0x757AFFFF},
{0x757C0000,0x75BFFFFF},
{0x76180000,0x761BFFFE},
{0x761C0000,0x761FFFFF},
{0x76400000,0x7642FFFF},
{0x76437000,0x76437FFF},
{0x76480000,0x7651FFFF},
{0x76540000,0x7655FFFF},
{0x76582000,0x7659FFFF},
{0x765BF000,0x765BFFFF},
{0x76661000,0x766627FF},
{0x76700000,0x767EFFFF},
{0x767F8000,0x767F9FFF},
{0x76840000,0x7687FFFF},
{0x76900000,0x7693FFFF},
{0x76B20000,0x76B2FFFF},
{0x76B40000,0x76B8FFFF},
{0x76B94000,0x76B97FFF},
{0x76BA0000,0x76BCFFFF},
{0x76BE0000,0x76C7FFFF},
{0x76C90000,0x76CFFFFF},
{0x76D40000,0x76D5FFFF},
{0x76E00000,0x76E6FFFF},
{0x76EF0000,0x76EFFFFF},
{0x76F20000,0x76F2FFFF},
{0x76F40000,0x77021FFF},
{0x77028000,0x7708FFFF},
{0x770A0000,0x770A7FFF},
{0x770F8800,0x770F8FFF},
{0x77100000,0x7710FFFF},
{0x7712C000,0x7712D7FF},
{0x7712E000,0x7717FFFF},
{0x771B4000,0x771DFFFF},
{0x771E3000,0x771E3FFF},
{0x771FC000,0x771FDFFF},
{0x77200000,0x77284FFF},
{0x77288000,0x772A1FFF},
{0x772A8000,0x772A8FFF},
{0x772AE000,0x772AFFFF},
{0x772C0000,0x772DFFFF},
{0x77300000,0x7737FFFF},
{0x77390000,0x773AFFFF},
{0x773B8000,0x773EFFFF},
{0x773F2000,0x773F3FFF},
{0x774BD000,0x774BDFFF},
{0x774E0000,0x7750FFFF},
{0x7752D000,0x7752DFFF},
{0x77540000,0x775BFFFF},
{0x77600000,0x7767FFFF},
{0x776C0000,0x776DFFFF},
{0x77700000,0x7793FFFF},
{0x7794A000,0x7794BFFF},
{0x7797C000,0x7797FFFF},
{0x77A0C800,0x77A0CFFF},
{0x77A18000,0x77A7FFFF},
{0x77B00000,0x77BFFFFF},
{0x77E80000,0x77E9FFFF},
{0x77EB8000,0x77EBBFFF},
{0x77F80000,0x77FBFFFF},
{0x77FC6000,0x77FC67FF},
{0x77FCF000,0x780FFFFF},
{0x78180000,0x781BFFFF},
{0x781E0000,0x7831FFFF},
{0x78340000,0x7837FFFF},
{0x78400000,0x7847FFFF},
{0x78482000,0x78483FFF},
{0x78488000,0x7848FFFF},
{0x784C0000,0x7857FFFF},
{0x78580800,0x78580FFF},
{0x785A0000,0x785CFFFF},
{0x785E0000,0x785FFFFF},
{0x78800000,0x7887FFFF},
{0x78888000,0x7888BFFF},
{0x78890000,0x78897FFF},
{0x788F8000,0x788F9FFF},
{0x78C00000,0x78FFFFFF},
{0x79000800,0x79001FFF},
{0x79040000,0x7905FFFF},
{0x79080000,0x792BFFFF},
{0x792E0000,0x7931FFFF},
{0x79320800,0x79320FFF},
{0x79330000,0x7933FFFF},
{0x7934A000,0x7934BFFF},
{0x7934D000,0x7934FFFF},
{0x7936B000,0x7936B7FF},
{0x79370000,0x79373FFF},
{0x79380000,0x793A7FFF},
{0x793A8800,0x793AA7FF},
{0x793B0000,0x793FFFFF},
{0x79440000,0x7947FFFF},
{0x794C0000,0x794DFFFF},
{0x794F8000,0x794FBFFF},
{0x79590000,0x7959FFFF},
{0x79648000,0x79653FFF},
{0x7965D000,0x7965DFFF},
{0x79C00000,0x79C7FFFF},
{0x79C8C000,0x79C8C7FF},
{0x79C90000,0x79C9FFFF},
{0x79CC0000,0x79CFFFFF},
{0x79E00000,0x79EFFFFF},
{0x79F80000,0x79FBFFFF},
{0x79FF0000,0x79FFFFFF},
{0x7A004000,0x7A00FFFF},
{0x7A040000,0x7A09FFFF},
{0x7A0A8000,0x7A0AC7FF},
{0x7A0AD800,0x7A0B7FFF},
{0x7A0C0000,0x7A0E7FFF},
{0x7A0EC000,0x7A0FFDFF},
{0x7A300000,0x7A313FFF},
{0x7A330000,0x7A33FFFF},
{0x7A400000,0x7A61FFFF},
{0x7A660000,0x7A660FFF},
{0x7A664000,0x7A665FFF},
{0x7A700000,0x7A733FFF},
{0x7A735000,0x7A73FFFF},
{0x7A770000,0x7A77FFFF},
{0x7A807800,0x7A807FFF},
{0x7A880000,0x7A8FFFFF},
{0x7A908000,0x7A90FFFF},
{0x7A98C000,0x7A98FFFF},
{0x7A9C0000,0x7A9FFFFF},
{0x7ABC0000,0x7AC3FFFF},
{0x7AC60000,0x7AC6FFFF},
{0x7AC84000,0x7AC87FFF},
{0x7AC93000,0x7AC93FFF},
{0x7ACC0000,0x7ACFFFFF},
{0x7AE00000,0x7AF7FFFF},
{0x7AF81800,0x7AF81FFF},
{0x7AF83000,0x7AF83FFF},
{0x7AFF4000,0x7AFF47FF},
{0x7B008000,0x7B00BFFF},
{0x7B040000,0x7B0FFFFF},
{0x7B318000,0x7B31FFFF},
{0x7B32A000,0x7B32BFFF},
{0x7B340000,0x7B3EFFFF},
{0x7B400000,0x7B627FFF},
{0x7B638000,0x7B641FFF},
{0x7B650000,0x7B65FFFF},
{0x7B670000,0x7B677FFF},
{0x7B6C8000,0x7B6C8FFF},
{0x7B6CD000,0x7B6CDFFF},
{0x7B700000,0x7B87FFFF},
{0x7B885000,0x7B885FFF},
{0x7B890000,0x7B8BFFFF},
{0x7B900000,0x7BAFFFFF},
{0x7BB03C00,0x7BB03FFF},
{0x7BB05000,0x7BB05FFF},
{0x7BB10000,0x7BBFFFFF},
{0x7BC40000,0x7BC5FFFF},
{0x7BC78000,0x7BC7FFFF},
{0x7BCE0000,0x7BCFFFFF},
{0x7BE80000,0x7BEBFFFF},
{0x7BF20000,0x7BF27FFF},
{0x7BF40000,0x7BF7FFFF},
{0x7BF90000,0x7BF9FFFF},
{0x7BFD0000,0x7BFDFFFF},
{0x7C064000,0x7C067FFF},
{0x7C0E0000,0x7C11FFFF},
{0x7C140000,0x7C17FFFF},
{0x7C1CC000,0x7C1D7FFF},
{0x7C1F0000,0x7C1FFFFF},
{0x7C287000,0x7C28DFFF},
{0x7C2A0000,0x7C2AFFFF},
{0x7C2F0000,0x7C2F3FFF},
{0x7C400000,0x7C427FFF},
{0x7C430000,0x7C4FFFFF},
{0x7C580000,0x7C5FFFFF},
{0x7C6C0800,0x7C6C0FFF},
{0x7C6C2800,0x7C6C2FFF},
{0x7C6D6000,0x7C6D67FF},
{0x7C700000,0x7C77FFFF},
{0x7C7E0000,0x7C87FFFF},
{0x7C938000,0x7C93FFFF},
{0x7C970000,0x7C98FFFF},
{0x7C9C0000,0x7C9CFFFF},
{0x7CA00000,0x7CA7FFFF},
{0x7CAC0000,0x7CAFFFFF},
{0x7CC00000,0x7CC1FFFF},
{0x7CC40000,0x7CC4FFFF},
{0x7CC80000,0x7CCFFFFF},
{0x7CDC0000,0x7CF0BFFF},
{0x7CF20000,0x7CF2FFFF},
{0x7CF3C000,0x7CF3FFFF},
{0x7CF80000,0x7CF87FFF},
{0x7CF90000,0x7CFBFFFF},
{0x7CFE0000,0x7CFE3FFF},
{0x7D1FC000,0x7D2FFFFF},
{0x7D3A8000,0x7D3AFFFF},
{0x7D3D8000,0x7D3E3FFF},
{0x7D400000,0x7D62FFFF},
{0x7D680000,0x7D7FFFFF},
{0x7DA90000,0x7DA9FFFF},
{0x7DAB0000,0x7DABFFFF},
{0x7DD00000,0x7DD03FFF},
{0x7DD20000,0x7DD3FFFF},
{0x7DD50000,0x7DD57FFF},
{0x7DD66000,0x7DD67FFF},
{0x7DD70000,0x7DD73FFF},
{0x7DD80000,0x7DDFFFFF},
{0x7DFE8000,0x7DFEFFFF},
{0x80CC9120,0x80CC912F},
{0x83E4BC00,0x83E4BDFF},
{0x86C40000,0x86C4FFFF},
{0x8B090000,0x8B09FFFF},
{0x8B810000,0x8B81FFFF},
{0x8B940000,0x8B94FFFF},
{0x8B9B0000,0x8B9BFFFF},
{0x8B9F0000,0x8B9FFFFF},
{0x8BAA0000,0x8BAAFFFF},
{0x8BB00000,0x8BB0FFFF},
{0x8BB70000,0x8BB7FFFF},
{0x8BBA0000,0x8BBAFFFF},
{0x8BBD0000,0x8BBDFFFF},
{0x8BC40000,0x8BD7FFFF},
{0x8BDC0000,0x8BDDFFFF},
{0x8BE00000,0x8BE0FFFF},
{0x8BE20000,0x8BE3FFFF},
{0x8C4B0000,0x8C4BFFFF},
{0x8C8F0000,0x8C8FFFFF},
{0x8CCD0000,0x8CCFFFFF},
{0x8CD20000,0x8CD2FFFF},
{0x8CE00000,0x8CE0FFFF},
{0x8CED0000,0x8CEDFFFF},
{0x8CF00000,0x8CF0FFFF},
{0x8CF20600,0x8CF206FF},
{0x8CF30000,0x8CF3FFFF},
{0x8CF60000,0x8CF6FFFF},
{0x8CF90000,0x8CFAFFFF},
{0x8CFF0000,0x8CFFFFFF},
{0x8E008000,0x8E00815F},
{0x8E008180,0x8E0081A7},
{0x8E0081B0,0x8E00823F},
{0x8E008260,0x8E0082FF},
{0x8E008308,0x8E0083BF},
{0x8E008400,0x8E00840F},
{0x8E008418,0x8E00841F},
{0x8E008430,0x8E00851F},
{0x8E008528,0x8E00853F},
{0x8E008550,0x8E0085AF},
{0x8E0085B8,0x8E0085DF},
{0x8E008600,0x8E00865F},
{0x8E008670,0x8E00881F},
{0x8E008840,0x8E0088CF},
{0x8E0088E0,0x8E0088EF},
{0x8E008900,0x8E008A7F},
{0x8E008A88,0x8E008B37},
{0x8E008B40,0x8E008B5F},
{0x8E008B70,0x8E008CBF},
{0x8E008CE0,0x8E008D9F},
{0x8E008DB0,0x8E008DC7},
{0x8E008DD0,0x8E008DD7},
{0x8E008DE0,0x8E008E6F},
{0x8E008F00,0x8E008FFF},
{0x8E046000,0x8E04605F},
{0x8E046080,0x8E0461FF},
{0x8E046220,0x8E04626F},
{0x8E046278,0x8E04629F},
{0x8E0462C0,0x8E04633F},
{0x8E046380,0x8E0463B7},
{0x8E0463C0,0x8E0463DF},
{0x8E046400,0x8E0464A7},
{0x8E0464B0,0x8E046547},
{0x8E046550,0x8E04655F},
{0x8E046570,0x8E0465AF},
{0x8E0465B8,0x8E04664F},
{0x8E046660,0x8E046667},
{0x8E046670,0x8E0466D7},
{0x8E0466E0,0x8E0468BF},
{0x8E0468E0,0x8E04690F},
{0x8E046920,0x8E04693F},
{0x8E046980,0x8E046A37},
{0x8E046A50,0x8E046A57},
{0x8E046A78,0x8E046A7F},
{0x8E046AC0,0x8E046C8F},
{0x8E046C98,0x8E046D0F},
{0x8E046D20,0x8E046D7F},
{0x8E046D90,0x8E046E07},
{0x8E046E10,0x8E046F7F},
{0x8E046FE0,0x8E04713F},
{0x8E047148,0x8E04721F},
{0x8E047240,0x8E0472A7},
{0x8E0472B0,0x8E0473C7},
{0x8E0473D0,0x8E0473E7},
{0x8E047400,0x8E047437},
{0x8E047440,0x8E0474AF},
{0x8E0474B8,0x8E04751B},
{0x8E047520,0x8E04753F},
{0x8E047550,0x8E0475DF},
{0x8E047600,0x8E0477FF},
{0x8E047880,0x8E047BFF},
{0x8E047D00,0x8E047E7F},
{0x8E047EB0,0x8E047EDF},
{0x8E047F00,0x8E047F2F},
{0x8E047F80,0x8E047FFF},
{0x90000000,0x9000FFFF},
{0x90070000,0x9007FFFF},
{0x900C0000,0x900CFFFF},
{0x90340000,0x9034FFFF},
{0x907B0000,0x907BFFFF},
{0x90FF0000,0x90FFFFFF},
{0x92F77A00,0x92F77A0F},
{0x93F3D800,0x93F3D8FF},
{0x93F3E000,0x93F3FFFF},
{0x96000000,0x9600FFFF},
{0x96730000,0x9673FFFF},
{0x96790000,0x967AFFFF},
{0x968A0000,0x968BFFFF},
{0x96DF0000,0x96DFFFFF},
{0x96FF0000,0x96FFFFFF},
{0x99000000,0x9900FFFF},
{0x99030000,0x9903FFFF},
{0x99220000,0x9925FFFF},
{0x99630000,0x9963FFFF},
{0x99650000,0x9965FFFF},
{0x99760000,0x9977FFFF},
{0x9D000000,0x9D00FFFF},
{0x9D120000,0x9D12FFFF},
{0x9D3D0000,0x9D3DFFFF},
{0x9D7A0000,0x9D7AFFFF},
{0x9D940000,0x9D94FFFF},
{0x9D9C0000,0x9D9CFFFF},
{0x9DFF0000,0x9DFFFFFF},
{0x9FE20000,0x9FE2FFFF},
{0x9FFD82D0,0x9FFD82DF},
{0x9FFD86D8,0x9FFD86DF},
{0x9FFD8724,0x9FFD8727},
{0x9FFD8868,0x9FFD886F},
{0x9FFD8960,0x9FFD8967},
{0x9FFD89AC,0x9FFD89AF},
{0x9FFD8B18,0x9FFD8B1F},
{0x9FFD8BB8,0x9FFD8BBF},
{0x9FFD8CA8,0x9FFD8CAB},
{0x9FFD8DA0,0x9FFD8DA7},
{0x9FFD8E50,0x9FFD8E57},
{0x9FFD9078,0x9FFD907F},
{0x9FFD9220,0x9FFD9227},
{0x9FFD9280,0x9FFD92A7},
{0x9FFD9381,0x9FFD9381},
{0x9FFD95F0,0x9FFD95F7},
{0x9FFD9740,0x9FFD975F},
{0x9FFD9875,0x9FFD9875},
{0xA03E0A00,0xA03E0AFF},
{0xA1CF0000,0xA1CFFFFF},
{0xA2690000,0xA269FFFF},
{0xA3000000,0xA300FFFF},
{0xA37D0000,0xA37DFFFF},
{0xA38E0000,0xA38EFFFF},
{0xA3B10000,0xA3B1FFFF},
{0xA3B30000,0xA3B3FFFF},
{0xA3CC0000,0xA3CCFFFF},
{0xA66F0000,0xA66FFFFF},
{0xA78B0000,0xA78BFFFF},
{0xA8A00000,0xA8A0FFFF},
{0xA8A1E000,0xA8A1E3FF},
{0xAB080000,0xAB0FFFFF},
{0xAB220000,0xAB2FFFFF},
{0xAB500000,0xAB5FFFFF},
{0xAB680000,0xAB7FFFFF},
{0xABD00000,0xABDFFFFF},
{0xAD019E30,0xAD019E3F},
{0xAD2C86A0,0xAD2C86A7},
{0xAD2CABD8,0xAD2CABDF},
{0xAD2CBF30,0xAD2CBF37},
{0xAD2CF680,0xAD2CF687},
{0xAD2CF6A8,0xAD2CF6AF},
{0xAD2CF8F0,0xAD2CF8F7},
{0xAD2D1200,0xAD2D12FF},
{0xADD54C38,0xADD54C3F},
{0xADE7C100,0xADE7C37F},
{0xADE7C400,0xADE7C87F},
{0xADE7C900,0xADE7CB7F},
{0xADE7CC80,0xADE7CCFF},
{0xADE7CE00,0xADE7CE7F},
{0xADE7CF00,0xADE7CF7F},
{0xADE7D000,0xADE7D07F},
{0xADE7D280,0xADE7D3FF},
{0xADE7D580,0xADE7D67F},
{0xADE7D800,0xADE7D8FF},
{0xADE7DB00,0xADE7DB7F},
{0xADE7DF00,0xADE7DFFF},
{0xADE7E380,0xADE7E4FF},
{0xADE7E600,0xADE7E77F},
{0xADE7E880,0xADE7E9FF},
{0xADE7EB80,0xADE7EBFF},
{0xADE7ED00,0xADE7ED7F},
{0xADE7EF00,0xADE7EF7F},
{0xADE7F480,0xADE7F4FF},
{0xADE7FA80,0xADE7FBFF},
{0xADE7FD00,0xADE7FD7F},
{0xADE80830,0xADE8083F},
{0xADE89560,0xADE89567},
{0xADEAD380,0xADEAD387},
{0xADF54410,0xADF54417},
{0xADF54800,0xADF54807},
{0xADF54818,0xADF5481F},
{0xADF54828,0xADF5482F},
{0xADF54850,0xADF5485F},
{0xADF54E20,0xADF54E27},
{0xADF54E30,0xADF54E3F},
{0xADF54EA0,0xADF54EDF},
{0xADF54F20,0xADF54F3F},
{0xADF9CF00,0xADF9CFFF},
{0xADFD4000,0xADFD47FF},
{0xADFD5000,0xADFD5FFF},
{0xADFD6200,0xADFD7007},
{0xADFD7040,0xADFD7047},
{0xADFD7108,0xADFD710F},
{0xADFD7130,0xADFD7137},
{0xADFD7150,0xADFD715F},
{0xADFD71D8,0xADFD71DF},
{0xADFD7250,0xADFD7257},
{0xADFD7280,0xADFD7287},
{0xADFD72D0,0xADFD72D7},
{0xADFD7308,0xADFD730F},
{0xADFD7360,0xADFD7367},
{0xADFD7390,0xADFD7397},
{0xADFD73A8,0xADFD73AF},
{0xADFD73F0,0xADFD73F7},
{0xADFD74A0,0xADFD74A7},
{0xADFD74C8,0xADFD74CF},
{0xADFD74F0,0xADFD74FF},
{0xADFD7558,0xADFD7567},
{0xADFD7570,0xADFD7577},
{0xADFD7580,0xADFD7587},
{0xADFD7590,0xADFD7597},
{0xADFD75B8,0xADFD75BF},
{0xADFD75D0,0xADFD75D7},
{0xADFD7648,0xADFD7657},
{0xADFD76B0,0xADFD76B7},
{0xADFD7710,0xADFD7717},
{0xADFD7728,0xADFD772F},
{0xADFD7738,0xADFD773F},
{0xADFD7768,0xADFD7777},
{0xADFD7788,0xADFD778F},
{0xADFD77A8,0xADFD77AF},
{0xADFD7808,0xADFD780F},
{0xADFD7850,0xADFD785F},
{0xADFD7878,0xADFD787F},
{0xADFD7990,0xADFD7997},
{0xADFD7A10,0xADFD7A17},
{0xADFD7A58,0xADFD7A5F},
{0xADFD7A70,0xADFD7A77},
{0xADFD7A98,0xADFD7AAF},
{0xADFD7B08,0xADFD7B0F},
{0xADFD7BF8,0xADFD7BFF},
{0xADFD7C18,0xADFD7C1F},
{0xADFD7C58,0xADFD7C5F},
{0xADFD7C78,0xADFD7C7F},
{0xADFD7CB8,0xADFD7CC7},
{0xADFD7D50,0xADFD7D57},
{0xADFD7DA8,0xADFD7DAF},
{0xADFD7DB8,0xADFD7DBF},
{0xADFF0238,0xADFF023F},
{0xADFF0288,0xADFF028F},
{0xADFF0550,0xADFF0557},
{0xAE8868C8,0xAE8868CF},
{0xAF000000,0xAF1BFFFF},
{0xAF1E0000,0xAF1FFFFF},
{0xAF2A0000,0xAF2CFFFF},
{0xAF2E0000,0xAF5FFFFF},
{0xAF660000,0xAF66FFFF},
{0xAF6A8000,0xAF6AFFFF},
{0xAF920000,0xAF9BFFFF},
{0xAFA00000,0xAFAFFFFF},
{0xAFB20000,0xAFB2FFFF},
{0xAFB88000,0xAFB8BFFF},
{0xAFB90000,0xAFBFFFFF},
{0xB212F640,0xB212F647},
{0xB2A28B00,0xB2A28BFF},
{0xB2AE1380,0xB2AE13FF},
{0xB2AF86E8,0xB2AF86EF},
{0xB2ECE204,0xB2ECE207},
{0xB44C0000,0xB44FFFFF},
{0xB4540000,0xB456FFFF},
{0xB4580000,0xB45BFFFF},
{0xB45E3800,0xB45E3FFF},
{0xB45E6000,0xB45E6FFF},
{0xB45F8000,0xB47FFFFF},
{0xB4818000,0xB482FFFF},
{0xB4880000,0xB48FFFFF},
{0xB4941000,0xB49417FF},
{0xB4949800,0xB4949FFF},
{0xB494D800,0xB494FFFF},
{0xB4958000,0xB4959FFF},
{0xB496A000,0xB496BFFF},
{0xB4980000,0xB4AFFFFF},
{0xB4B2C000,0xB4B2FFFF},
{0xB4B80000,0xB4BC7FFF},
{0xB4BD9400,0xB4BD97FF},
{0xB4C8FC00,0xB4CBFFFF},
{0xB4D00000,0xB4D1FFFF},
{0xB4D2E000,0xB4D2FFFF},
{0xB4D40000,0xB4D5FFFF},
{0xB4DEE000,0xB4DFFFFF},
{0xB4E90000,0xB4E95FFF},
{0xB4EB4000,0xB4EB5FFF},
{0xB610C000,0xB610DFFF},
{0xB6120000,0xB6127FFF},
{0xB617B800,0xB617BFFF},
{0xB617C800,0xB617CFFF},
{0xB6200000,0xB62FFFFF},
{0xB6306000,0xB6307FFF},
{0xB6310000,0xB6320FFF},
{0xB6327000,0xB6327FFF},
{0xB6330000,0xB633FFFF},
{0xB6360000,0xB6367FFF},
{0xB63D0000,0xB63DFFFF},
{0xB6500000,0xB65CFFFF},
{0xB6600000,0xB697FFFF},
{0xB69D0000,0xB69DFFFF},
{0xB6A04000,0xB6A05FFF},
{0xB6AE0000,0xB6AFFFFF},
{0xB6C80000,0xB6CFFFFF},
{0xB6EC8000,0xB6ECFFFF},
{0xB6EE0000,0xB6EF1FFF},
{0xB6F00000,0xB6F7FFFF},
{0xB6FE0000,0xB6FEFFFF},
{0xB7000000,0xB747FFFF},
{0xB74EB400,0xB74EB7FF},
{0xB751B400,0xB751B7FF},
{0xB7540000,0xB755FFFF},
{0xB75B8000,0xB75B83FF},
{0xB75B8800,0xB75B9FFF},
{0xB75C0000,0xB75FFFFF},
{0xB7800000,0xB7AAFFFF},
{0xB7AC0000,0xB7AFFFFF},
{0xB7B60000,0xB7B61FFF},
{0xB7B80000,0xB7FFFFFF},
{0xB85F2360,0xB85F237F},
{0xB8ACB5F0,0xB8ACB5F7},
{0xB9086810,0xB908683F},
{0xB9086860,0xB9086867},
{0xB9086880,0xB90868EF},
{0xBC8A4F8E,0xBC8A4F8E},
{0xBC8A4F94,0xBC8A4F94},
{0xBC8A5376,0xBC8A5376},
{0xBC8A78A9,0xBC8A78A9},
{0xC0001100,0xC000111F},
{0xC04AE030,0xC04AE03F},
{0xC04AE060,0xC04AE07F},
{0xC04AE090,0xC04AE0E7},
{0xC04AE100,0xC04AE2BF},
{0xC04AE300,0xC04AE4EF},
{0xC04AE4F8,0xC04AE707},
{0xC04AE710,0xC04AE78F},
{0xC04AE800,0xC04AE8BF},
{0xC04AE900,0xC04AEABF},
{0xC04AEAC8,0xC04AEADF},
{0xC04AEAE8,0xC04AEAEF},
{0xC04AEB00,0xC04AEB47},
{0xC04AEB50,0xC04AEC3F},
{0xC04AEC50,0xC04AED3F},
{0xC04AED80,0xC04AEE8F},
{0xC04AEE98,0xC04AEEC7},
{0xC04AEED0,0xC04AEEDF},
{0xC04AEEE8,0xC04AEF9F},
{0xC04AEFA8,0xC04AEFFF},
{0xC04AF020,0xC04AF0E7},
{0xC04AF0F0,0xC04AF19F},
{0xC04AF1A8,0xC04AF27F},
{0xC04AF288,0xC04AF2BF},
{0xC04AF300,0xC04AF45F},
{0xC04AF468,0xC04AF46F},
{0xC04AF500,0xC04AF55F},
{0xC04AF600,0xC04AF63F},
{0xC04AF648,0xC04AF6FF},
{0xC04AF800,0xC04AF91F},
{0xC04AF980,0xC04AFA1F},
{0xC04AFA30,0xC04AFA87},
{0xC04AFAC0,0xC04AFAFF},
{0xC04AFC00,0xC04AFC17},
{0xC04AFC40,0xC04AFCBF},
{0xC04AFD00,0xC04AFE7F},
{0xC04AFF00,0xC04AFFFF},
{0xC07C9A00,0xC07C9AFF},
{0xC0891F00,0xC0891FFF},
{0xC097FF00,0xC097FFFF},
{0xC0A15C00,0xC0A15FFF},
{0xC0BCAA00,0xC0BCAAFF},
{0xC1DC7000,0xC1DC70FF},
{0xC275652D,0xC275652D},
{0xC2756537,0xC2756537},
{0xC275672B,0xC275672B},
{0xC275673A,0xC275673A},
{0xC275674E,0xC275674F},
{0xC2756778,0xC2756778},
{0xC275677B,0xC275677B},
{0xC2756796,0xC2756796},
{0xC275679A,0xC275679B},
{0xC27567B5,0xC27567B5},
{0xC27567BD,0xC27567BD},
{0xC27567C3,0xC27567C3},
{0xC27567CE,0xC27567CE},
{0xC27567D7,0xC27567D7},
{0xC27567DA,0xC27567DB},
{0xC27567E6,0xC27567E6},
{0xC2757765,0xC2757765},
{0xC370A714,0xC370A717},
{0xC370A738,0xC370A73B},
{0xC370A754,0xC370A757},
{0xC370A79C,0xC370A7A3},
{0xC370B114,0xC370B117},
{0xC370B120,0xC370B123},
{0xC370B17C,0xC370B17F},
{0xC370BF0C,0xC370BF0C},
{0xC60738C0,0xC60738CF},
{0xC60F43F0,0xC60F43F7},
{0xC60F4540,0xC60F457F},
{0xC60F5780,0xC60F5787},
{0xC60F5800,0xC60F583F},
{0xC6102000,0xC61037FF},
{0xC6283000,0xC62830FF},
{0xC6283200,0xC62833A7},
{0xC62833C0,0xC6283427},
{0xC6283430,0xC6283437},
{0xC6283440,0xC628360F},
{0xC6283618,0xC62836DF},
{0xC6283700,0xC6283797},
{0xC62837A0,0xC62837FF},
{0xC6283808,0xC62838EF},
{0xC62838F8,0xC62839BF},
{0xC6283A00,0xC6283A27},
{0xC6283A30,0xC6283A37},
{0xC6283A40,0xC6283C0F},
{0xC6283C40,0xC6283C7F},
{0xC6283CE0,0xC6283DBF},
{0xC6283F00,0xC6283FFF},
{0xC69A5848,0xC69A584F},
{0xC6B13800,0xC6B1389F},
{0xC6B138C0,0xC6B1397F},
{0xC6B139A0,0xC6B13B27},
{0xC6B13B30,0xC6B13C5F},
{0xC6B13C80,0xC6B13DAF},
{0xC6B13DC0,0xC6B13FFF},
{0xC6F43500,0xC6F436FF},
{0xC6F43B00,0xC6F43B3F},
{0xC6F43B80,0xC6F43BFF},
{0xC6F43D00,0xC6F43D7F},
{0xC6F43E00,0xC6F43EBF},
{0xC6F43F00,0xC6F43FFF},
{0xC703D200,0xC703D27F},
{0xC70F7402,0xC70F743E},
{0xC70F7442,0xC70F747E},
{0xC70F7700,0xC70F77FF},
{0xC710CE88,0xC710CE8F},
{0xC7136819,0xC7136857},
{0xC7227CC8,0xC7227CCF},
{0xC726F1E0,0xC726F1E7},
{0xC726F280,0xC726F29F},
{0xC726F2E0,0xC726F2FF},
{0xC726F320,0xC726F33F},
{0xC72E7D00,0xC72E7D7F},
{0xC72E7DD0,0xC72E7DD7},
{0xC72E7E58,0xC72E7E5F},
{0xC72E7EA8,0xC72E7EAF},
{0xC7656420,0xC765643F},
{0xC7656540,0xC765657F},
{0xC7659038,0xC765903F},
{0xC76592D8,0xC76592DF},
{0xC76593A0,0xC76593A7},
{0xC766E0EC,0xC766E0EF},
{0xC766E498,0xC766E49B},
{0xC7B46430,0xC7B4643F},
{0xC7B46498,0xC7B4649F},
{0xC7B464B8,0xC7B464BF},
{0xC7B464D0,0xC7B464D7},
{0xC7B46528,0xC7B4652F},
{0xC7B46588,0xC7B4658F},
{0xC7B46598,0xC7B4659F},
{0xC7B465B0,0xC7B465BF},
{0xC7B46600,0xC7B4661F},
{0xC7B466A8,0xC7B466AF},
{0xC7B46710,0xC7B46717},
{0xC7B46780,0xC7B467BF},
{0xC7B467E8,0xC7B467EF},
{0xC7BC6808,0xC7BC680F},
{0xC7BC6820,0xC7BC683F},
{0xC7BC6848,0xC7BC68BF},
{0xC7BC6900,0xC7BC692F},
{0xC7BC6940,0xC7BC6AAF},
{0xC7BC6AC0,0xC7BC6B27},
{0xC7BC6B40,0xC7BC6B7F},
{0xC7BC6BC0,0xC7BC6BE7},
{0xC7BC6C00,0xC7BC6CBF},
{0xC7BC6D00,0xC7BC6D07},
{0xC7BC6D10,0xC7BC6D5F},
{0xC7BC6D80,0xC7BC6D8F},
{0xC7BC6D98,0xC7BC6DBF},
{0xC7BC6E00,0xC7BC6E1F},
{0xC7BC6E80,0xC7BC6EEF},
{0xC7BC6EF8,0xC7BC6EFF},
{0xC7BC6F40,0xC7BC6F47},
{0xC7BC6F58,0xC7BC6F5F},
{0xC7BC6F70,0xC7BC6F7F},
{0xC7BC6F88,0xC7BC6F9F},
{0xC7BC6FB0,0xC7BC6FBF},
{0xC7E5E3A0,0xC7E5E3BF},
{0xC7E74000,0xC7E7400F},
{0xC7E74020,0xC7E7405F},
{0xC7E74065,0xC7E74066},
{0xC7E74068,0xC7E7406F},
{0xC7E74071,0xC7E74074},
{0xC7E74076,0xC7E74076},
{0xC7E74078,0xC7E7407A},
{0xC7E7407D,0xC7E7407D},
{0xC7E74080,0xC7E740BF},
{0xC7E74100,0xC7E741DF},
{0xC7E74200,0xC7E74217},
{0xC7E74220,0xC7E742BF},
{0xC7E74320,0xC7E7439F},
{0xC7E74400,0xC7E74407},
{0xC7E74410,0xC7E74417},
{0xC7E74420,0xC7E744A7},
{0xC7E744B0,0xC7E745DF},
{0xC7E74600,0xC7E746F7},
{0xC7E74700,0xC7E74707},
{0xC7E74710,0xC7E747FF},
{0xC7E7E498,0xC7E7E49F},
{0xC7E7E4F8,0xC7E7E4FF},
{0xC7E7E720,0xC7E7E727},
{0xC7F1B8FC,0xC7F1B8FF},
{0xC7F1BA18,0xC7F1BA1B},
{0xC7F1BA20,0xC7F1BA27},
{0xC7F1BAD0,0xC7F1BADF},
{0xC7F1BEC8,0xC7F1BECF},
{0xC7F53D00,0xC7F53DFF},
{0xC7FF9DE0,0xC7FF9DFF},
{0xCA006400,0xCA0065FF},
{0xCA007A00,0xCA007BFF},
{0xCA038000,0xCA0381FF},
{0xCA048000,0xCA049FFF},
{0xCA04FC00,0xCA04FFFF},
{0xCA060600,0xCA0607FF},
{0xCA064200,0xCA0643FF},
{0xCA064800,0xCA0649FF},
{0xCA065700,0xCA0659FF},
{0xCA065C00,0xCA065DFF},
{0xCA066700,0xCA0667FF},
{0xCA066C00,0xCA066CFF},
{0xCA066E00,0xCA066FFF},
{0xCA067200,0xCA0672FF},
{0xCA06B000,0xCA06BFFF},
{0xCA080000,0xCA0800FF},
{0xCA080200,0xCA0805FF},
{0xCA080C00,0xCA080CFF},
{0xCA081800,0xCA0818FF},
{0xCA084D00,0xCA084DFF},
{0xCA088000,0xCA089FFF},
{0xCA08C000,0xCA08CFFF},
{0xCA092000,0xCA0920FF},
{0xCA092200,0xCA0923FF},
{0xCA093000,0xCA0931FF},
{0xCA093300,0xCA0937FF},
{0xCA093900,0xCA093BFF},
{0xCA0A4000,0xCA0A4FFF},
{0xCA0C0100,0xCA0C02FF},
{0xCA0C1100,0xCA0C13FF},
{0xCA0C4800,0xCA0C48FF},
{0xCA0C5400,0xCA0C55FF},
{0xCA0C6000,0xCA0C60FF},
{0xCA0C6200,0xCA0C63FF},
{0xCA0C6A00,0xCA0C6AFF},
{0xCA0C6F00,0xCA0C6FFF},
{0xCA0C7400,0xCA0C74FF},
{0xCA0E4000,0xCA0E41FF},
{0xCA0E4500,0xCA0E45FF},
{0xCA0E4900,0xCA0E4CFF},
{0xCA0E4E00,0xCA0E4FFF},
{0xCA0E5800,0xCA0E58FF},
{0xCA0E6100,0xCA0E61FF},
{0xCA0E6800,0xCA0E69FF},
{0xCA0E6C00,0xCA0E6DFF},
{0xCA0E6F00,0xCA0E6FFF},
{0xCA0E7200,0xCA0E73FF},
{0xCA0E7600,0xCA0E77FF},
{0xCA0E7C00,0xCA0E7DFF},
{0xCA0E7F00,0xCA0E7FFF},
{0xCA0E8100,0xCA0E81FF},
{0xCA0E8700,0xCA0E88FF},
{0xCA0E9500,0xCA0E95FF},
{0xCA0E9700,0xCA0E97FF},
{0xCA0E9D00,0xCA0E9FFF},
{0xCA0EA900,0xCA0EABFF},
{0xCA0EB000,0xCA0EB0FF},
{0xCA0EB800,0xCA0EB9FF},
{0xCA0ED000,0xCA0ED1FF},
{0xCA0ED500,0xCA0ED5FF},
{0xCA0EDB00,0xCA0EDCFF},
{0xCA0EDE00,0xCA0EE3FF},
{0xCA0EE700,0xCA0EE7FF},
{0xCA0EEB00,0xCA0EEFFF},
{0xCA0EF600,0xCA0EF6FF},
{0xCA0EFB00,0xCA0EFBFF},
{0xCA145700,0xCA145AFF},
{0xCA145E00,0xCA145FFF},
{0xCA147200,0xCA1472FF},
{0xCA147500,0xCA1475FF},
{0xCA147800,0xCA1478FF},
{0xCA147D00,0xCA147DFF},
{0xCA147F00,0xCA147FFF},
{0xCA158300,0xCA1584FF},
{0xCA158D00,0xCA158EFF},
{0xCA159300,0xCA1594FF},
{0xCA159600,0xCA159AFF},
{0xCA159C00,0xCA159CFF},
{0xCA16F800,0xCA16FFFF},
{0xCA1B8800,0xCA1B89FF},
{0xCA260000,0xCA2603FF},
{0xCA260800,0xCA260FFF},
{0xCA263000,0xCA268AFF},
{0xCA268C00,0xCA268FFF},
{0xCA269200,0xCA2693FF},
{0xCA269500,0xCA269CFF},
{0xCA269E00,0xCA26A1FF},
{0xCA26A400,0xCA26ABFF},
{0xCA26B000,0xCA26B1FF},
{0xCA26B800,0xCA26FFFF},
{0xCA280400,0xCA2805FF},
{0xCA280700,0xCA2807FF},
{0xCA280F00,0xCA280FFF},
{0xCA288700,0xCA2888FF},
{0xCA288C00,0xCA288CFF},
{0xCA288F00,0xCA2891FF},
{0xCA289600,0xCA2896FF},
{0xCA289B00,0xCA289CFF},
{0xCA289E00,0xCA289FFF},
{0xCA28A200,0xCA28A2FF},
{0xCA290800,0xCA2909FF},
{0xCA290B00,0xCA290DFF},
{0xCA298000,0xCA2980FF},
{0xCA298200,0xCA2983FF},
{0xCA299800,0xCA299FFF},
{0xCA29C000,0xCA29C0FF},
{0xCA29F000,0xCA29FFFF},
{0xCA2B4C00,0xCA2B4FFF},
{0xCA2B9000,0xCA2B9FFF},
{0xCA2C1000,0xCA2C1FFF},
{0xCA2C4300,0xCA2C43FF},
{0xCA2C4A00,0xCA2C4AFF},
{0xCA2C8100,0xCA2C81FF},
{0xCA2C8400,0xCA2C85FF},
{0xCA2C9200,0xCA2C93FF},
{0xCA2D0000,0xCA2D02FF},
{0xCA2D0F00,0xCA2D1FFF},
{0xCA2E1000,0xCA2E12FF},
{0xCA2E1400,0xCA2E15FF},
{0xCA2E2000,0xCA2E3FFF},
{0xCA2E8000,0xCA2E80FF},
{0xCA2EE000,0xCA2EEFFF},
{0xCA2F5200,0xCA2F53FF},
{0xCA2F7E00,0xCA2F7EFF},
{0xCA2F8000,0xCA2F80FF},
{0xCA2F8200,0xCA2F83FF},
{0xCA39F000,0xCA3A00FF},
{0xCA3B0000,0xCA3B00FF},
{0xCA3BD400,0xCA3BD7FF},
{0xCA3BE800,0xCA3BE9FF},
{0xCA3BEC00,0xCA3BECFF},
{0xCA3C3000,0xCA3C37FF},
{0xCA3C6000,0xCA3C67FF},
{0xCA3C7000,0xCA3C7FFF},
{0xCA3C8400,0xCA3C9FFF},
{0xCA3E7000,0xCA3E73FF},
{0xCA3EF800,0xCA3EFCFF},
{0xCA3EFF00,0xCA3EFFFF},
{0xCA3F5100,0xCA3F5FFF},
{0xCA3FA000,0xCA3FBFFF},
{0xCA3FF800,0xCA3FFBFF},
{0xCA410000,0xCA4109FF},
{0xCA430000,0xCA4303FF},
{0xCA450400,0xCA4507FF},
{0xCA451000,0xCA451FFF},
{0xCA460000,0xCA461FFF},
{0xCA466000,0xCA466FFF},
{0xCA46C000,0xCA46CFFF},
{0xCA482800,0xCA482FFF},
{0xCA485000,0xCA485FFF},
{0xCA498000,0xCA4983FF},
{0xCA4A0800,0xCA4A0FFF},
{0xCA4A5000,0xCA4A5FFF},
{0xCA4AFE00,0xCA4AFFFF},
{0xCA4BD000,0xCA4BDFFF},
{0xCA4BFC00,0xCA4BFFFF},
{0xCA4CF000,0xCA4CF0FF},
{0xCA4CFC00,0xCA4CFFFF},
{0xCA4D5000,0xCA4D57FF},
{0xCA4D5C00,0xCA4D5FFF},
{0xCA4E0800,0xCA4E0FFF},
{0xCA4FE000,0xCA4FE7FF},
{0xCA4FF800,0xCA4FFBFF},
{0xCA50C000,0xCA50CFFF},
{0xCA510000,0xCA5103FF},
{0xCA53FC00,0xCA53FFFF},
{0xCA540400,0xCA540FFF},
{0xCA541800,0xCA541FFF},
{0xCA55D000,0xCA55DFFF},
{0xCA56F900,0xCA56F9FF},
{0xCA56FC00,0xCA56FFFF},
{0xCA575000,0xCA575FFF},
{0xCA590800,0xCA590FFF},
{0xCA5A0000,0xCA5A03FF},
{0xCA5A7000,0xCA5A7FFF},
{0xCA5AC400,0xCA5AC4FF},
{0xCA5AE000,0xCA5AEFFF},
{0xCA5B0000,0xCA5B03FF},
{0xCA5B6000,0xCA5B6FFF},
{0xCA5B8000,0xCA5B83FF},
{0xCA5BB000,0xCA5BBFFF},
{0xCA5BE000,0xCA5C03FF},
{0xCA5C0800,0xCA5C0FFF},
{0xCA5C3000,0xCA5C3FFF},
{0xCA5CFC00,0xCA5D03FF},
{0xCA5DFC00,0xCA5DFFFF},
{0xCA5E5C00,0xCA5E5FFF},
{0xCA5F0000,0xCA5F1FFF},
{0xCA5FF000,0xCA5FF7FF},
{0xCA5FFC00,0xCA7A07FF},
{0xCA7A2000,0xCA7A27FF},
{0xCA7A4000,0xCA7A5FFF},
{0xCA7A7000,0xCA7A80FF},
{0xCA7A8400,0xCA7A84FF},
{0xCA7B6000,0xCA7B6FFF},
{0xCA7C1000,0xCA7C1BFF},
{0xCA7D7000,0xCA7D7FFF},
{0xCA7DB000,0xCA7DBFFF},
{0xCA7F0000,0xCA7F07FF},
{0xCA7F0C00,0xCA7F1FFF},
{0xCA7F2800,0xCA7F3FFF},
{0xCA7F7000,0xCA7FA7FF},
{0xCA7FC000,0xCA7FD1FF},
{0xCA7FD400,0xCA7FFFFF},
{0xCA820000,0xCA821FFF},
{0xCA82E000,0xCA82FFFF},
{0xCA831000,0xCA8317FF},
{0xCA833000,0xCA833FFF},
{0xCA83D000,0xCA83DFFF},
{0xCA852000,0xCA852FFF},
{0xCA863A00,0xCA863AFF},
{0xCA868000,0xCA868FFF},
{0xCA883000,0xCA883FFF},
{0xCA88D000,0xCA88EFFF},
{0xCA89E700,0xCA89E7FF},
{0xCA8DA000,0xCA8DBFFF},
{0xCA8E1000,0xCA8E1FFF},
{0xCA8F0400,0xCA8F07FF},
{0xCA8F1000,0xCA8F2FFF},
{0xCA8F3800,0xCA8F3FFF},
{0xCA92A000,0xCA92AFFF},
{0xCA92BC00,0xCA92BFFF},
{0xCA92C400,0xCA92CFFF},
{0xCA939000,0xCA939FFF},
{0xCA942000,0xCA942FFF},
{0xCA944000,0xCA947FFF},
{0xCA952000,0xCA953FFF},
{0xCA95A000,0xCA95BFFF},
{0xCA95E000,0xCA95FFFF},
{0xCA961000,0xCA962FFF},
{0xCA963800,0xCA963BFF},
{0xCA96C000,0xCA96CFFF},
{0xCA96E000,0xCA9703FF},
{0xCA978000,0xCA979FFF},
{0xCA98B000,0xCA98BFFF},
{0xCA990000,0xCA9903FF},
{0xCA993000,0xCA993FFF},
{0xCA9DC000,0xCA9DDFFF},
{0xCA9EA000,0xCA9EBFFF},
{0xCAA0B000,0xCAA0BFFF},
{0xCAA24300,0xCAA243FF},
{0xCAA24B00,0xCAA24BFF},
{0xCAA40000,0xCAA40FFF},
{0xCAA41900,0xCAA419FF},
{0xCAA46000,0xCAA47FFF},
{0xCAA5B000,0xCAA5BFFF},
{0xCAA5D000,0xCAA5DFFF},
{0xCAA5EF00,0xCAA5F1FF},
{0xCAA5F300,0xCAA5F3FF},
{0xCAA5F500,0xCAA5F5FF},
{0xCAA5FB00,0xCAA5FFFF},
{0xCAA6E000,0xCAA6FFFF},
{0xCAA8A000,0xCAA8BFFF},
{0xCAAA8000,0xCAAA9FFF},
{0xCAAAD800,0xCAAAFFFF},
{0xCAABD800,0xCAABDFFF},
{0xCAABEB00,0xCAABEBFF},
{0xCAAC0000,0xCAAC03FF},
{0xCAAD0000,0xCAAD03FF},
{0xCAAD0800,0xCAAD0FFF},
{0xCAADE000,0xCAADFFFF},
{0xCAAE4000,0xCAAE4FFF},
{0xCAB0E000,0xCAB0FFFF},
{0xCAB3F000,0xCAB3FFFF},
{0xCAB48000,0xCAB49FFF},
{0xCAB4D000,0xCAB4D7FF},
{0xCAB57000,0xCAB57FFF},
{0xCAB62000,0xCAB62FFF},
{0xCAB6C000,0xCAB6DFFF},
{0xCABD0000,0xCABD3FFF},
{0xCABD5000,0xCABD5FFF},
{0xCABDB800,0xCABDBFFF},
{0xCABF0000,0xCABF00FF},
{0xCABF4400,0xCABF5FFF},
{0xCAC00000,0xCACFFFFF},
{0xCB000400,0xCB0007FF},
{0xCB000A00,0xCB000BFF},
{0xCB001200,0xCB0012FF},
{0xCB001800,0xCB0018FF},
{0xCB002A00,0xCB002BFF},
{0xCB002D00,0xCB002FFF},
{0xCB005100,0xCB0053FF},
{0xCB005A00,0xCB005BFF},
{0xCB006000,0xCB0061FF},
{0xCB006800,0xCB006FFF},
{0xCB007200,0xCB0073FF},
{0xCB007A00,0xCB007AFF},
{0xCB008000,0xCB0080FF},
{0xCB008200,0xCB0087FF},
{0xCB008900,0xCB0089FF},
{0xCB008E00,0xCB008EFF},
{0xCB009000,0xCB0090FF},
{0xCB009200,0xCB0092FF},
{0xCB009400,0xCB0094FF},
{0xCB009600,0xCB0098FF},
{0xCB00B100,0xCB00B1FF},
{0xCB00E000,0xCB00E0FF},
{0xCB010400,0xCB0107FF},
{0xCB011200,0xCB0112FF},
{0xCB011A00,0xCB011BFF},
{0xCB014100,0xCB0143FF},
{0xCB014600,0xCB0147FF},
{0xCB014C00,0xCB014DFF},
{0xCB015A00,0xCB015AFF},
{0xCB016100,0xCB0167FF},
{0xCB016C00,0xCB016CFF},
{0xCB01FD00,0xCB01FEFF},
{0xCB024000,0xCB0247FF},
{0xCB024900,0xCB0249FF},
{0xCB027000,0xCB0277FF},
{0xCB027E00,0xCB027FFF},
{0xCB028C00,0xCB028CFF},
{0xCB029600,0xCB0296FF},
{0xCB029800,0xCB029DFF},
{0xCB02A000,0xCB02A7FF},
{0xCB02B400,0xCB02B5FF},
{0xCB02C400,0xCB02C5FF},
{0xCB02D100,0xCB02D1FF},
{0xCB02D600,0xCB02D7FF},
{0xCB02E200,0xCB02E3FF},
{0xCB02E500,0xCB02E5FF},
{0xCB02EC00,0xCB02EDFF},
{0xCB034400,0xCB0344FF},
{0xCB034800,0xCB0349FF},
{0xCB034B00,0xCB034BFF},
{0xCB035000,0xCB0357FF},
{0xCB036000,0xCB0363FF},
{0xCB036900,0xCB0369FF},
{0xCB037000,0xCB0378FF},
{0xCB037B00,0xCB037BFF},
{0xCB038700,0xCB0387FF},
{0xCB038B00,0xCB038BFF},
{0xCB038F00,0xCB038FFF},
{0xCB048400,0xCB0486FF},
{0xCB049700,0xCB049BFF},
{0xCB04AE00,0xCB04AFFF},
{0xCB04B400,0xCB04B4FF},
{0xCB04BA00,0xCB04BAFF},
{0xCB04CD00,0xCB04CDFF},
{0xCB04D000,0xCB04D3FF},
{0xCB04E300,0xCB04E3FF},
{0xCB04E600,0xCB04E7FF},
{0xCB050400,0xCB0505FF},
{0xCB050700,0xCB0509FF},
{0xCB050B00,0xCB050BFF},
{0xCB051500,0xCB0516FF},
{0xCB052C00,0xCB052CFF},
{0xCB052E00,0xCB052FFF},
{0xCB053400,0xCB0539FF},
{0xCB053C00,0xCB053DFF},
{0xCB057200,0xCB0573FF},
{0xCB057600,0xCB0576FF},
{0xCB057800,0xCB0578FF},
{0xCB05AC00,0xCB05ACFF},
{0xCB05B400,0xCB05B6FF},
{0xCB05B900,0xCB05BAFF},
{0xCB05BC00,0xCB05BEFF},
{0xCB05C300,0xCB05C3FF},
{0xCB05D600,0xCB05D7FF},
{0xCB05DA00,0xCB05DBFF},
{0xCB068300,0xCB0683FF},
{0xCB068800,0xCB0688FF},
{0xCB068A00,0xCB068BFF},
{0xCB068E00,0xCB068EFF},
{0xCB069600,0xCB0697FF},
{0xCB069D00,0xCB069DFF},
{0xCB069F00,0xCB069FFF},
{0xCB06E000,0xCB06EFFF},
{0xCB06F800,0xCB06F9FF},
{0xCB078100,0xCB0781FF},
{0xCB078A00,0xCB078BFF},
{0xCB079300,0xCB0793FF},
{0xCB079600,0xCB0797FF},
{0xCB079E00,0xCB079EFF},
{0xCB07C000,0xCB07C1FF},
{0xCB07C800,0xCB07C8FF},
{0xCB080000,0xCB0800FF},
{0xCB080800,0xCB0808FF},
{0xCB081700,0xCB081FFF},
{0xCB084600,0xCB0846FF},
{0xCB085200,0xCB0852FF},
{0xCB085600,0xCB0857FF},
{0xCB085B00,0xCB085BFF},
{0xCB086E00,0xCB086FFF},
{0xCB087300,0xCB0873FF},
{0xCB08A600,0xCB08A7FF},
{0xCB08A900,0xCB08A9FF},
{0xCB08AD00,0xCB08ADFF},
{0xCB08B800,0xCB08B8FF},
{0xCB08BA00,0xCB08BBFF},
{0xCB08BE00,0xCB08C0FF},
{0xCB08C500,0xCB08C7FF},
{0xCB08CB00,0xCB08CBFF},
{0xCB08D100,0xCB08D7FF},
{0xCB08D900,0xCB08D9FF},
{0xCB08DC00,0xCB08DCFF},
{0xCB092000,0xCB0920FF},
{0xCB092400,0xCB0925FF},
{0xCB093900,0xCB0939FF},
{0xCB093F00,0xCB093FFF},
{0xCB094100,0xCB0941FF},
{0xCB094600,0xCB0948FF},
{0xCB094B00,0xCB094DFF},
{0xCB096000,0xCB0965FF},
{0xCB096C00,0xCB096CFF},
{0xCB099E00,0xCB099EFF},
{0xCB0A2200,0xCB0A22FF},
{0xCB0A3800,0xCB0A38FF},
{0xCB0A4A00,0xCB0A4BFF},
{0xCB0A5400,0xCB0A58FF},
{0xCB0A5F00,0xCB0A5FFF},
{0xCB0A7D00,0xCB0A7DFF},
{0xCB0B4600,0xCB0B46FF},
{0xCB0B4C00,0xCB0B4FFF},
{0xCB0B5200,0xCB0B52FF},
{0xCB0B5400,0xCB0B57FF},
{0xCB0B6400,0xCB0B67FF},
{0xCB0B6D00,0xCB0B6DFF},
{0xCB0B7500,0xCB0B75FF},
{0xCB0B7A00,0xCB0B7AFF},
{0xCB0B7E00,0xCB0B7EFF},
{0xCB0B8800,0xCB0B8BFF},
{0xCB0B8D00,0xCB0B8FFF},
{0xCB0BB400,0xCB0BB7FF},
{0xCB0BD000,0xCB0BD3FF},
{0xCB0C1000,0xCB0C10FF},
{0xCB0C1300,0xCB0C13FF},
{0xCB0C1800,0xCB0C18FF},
{0xCB0C3900,0xCB0C39FF},
{0xCB0C4100,0xCB0C42FF},
{0xCB0C4600,0xCB0C47FF},
{0xCB0C5700,0xCB0C5FFF},
{0xCB0C6400,0xCB0C65FF},
{0xCB0C6700,0xCB0C67FF},
{0xCB0C7200,0xCB0C72FF},
{0xCB0C7600,0xCB0C76FF},
{0xCB0C8200,0xCB0C82FF},
{0xCB0C8900,0xCB0C89FF},
{0xCB0CC400,0xCB0CCFFF},
{0xCB0CD300,0xCB0CD3FF},
{0xCB0CDB00,0xCB0CDBFF},
{0xCB0CE200,0xCB0CE2FF},
{0xCB0CF000,0xCB0CF3FF},
{0xCB0D1200,0xCB0D12FF},
{0xCB0D1800,0xCB0D18FF},
{0xCB0D2C00,0xCB0D2DFF},
{0xCB0D5000,0xCB0D59FF},
{0xCB0D5C00,0xCB0D5FFF},
{0xCB0DAD00,0xCB0DADFF},
{0xCB0DE000,0xCB0DE1FF},
{0xCB0DE300,0xCB0DE3FF},
{0xCB0DE900,0xCB0DE9FF},
{0xCB0E1800,0xCB0E1BFF},
{0xCB0E2100,0xCB0E21FF},
{0xCB0E3800,0xCB0E38FF},
{0xCB0E3D00,0xCB0E3EFF},
{0xCB0E6800,0xCB0E68FF},
{0xCB0E7200,0xCB0E73FF},
{0xCB0E7600,0xCB0E76FF},
{0xCB0EA200,0xCB0EA2FF},
{0xCB0EB800,0xCB0EC0FF},
{0xCB0EC200,0xCB0EC3FF},
{0xCB0ED600,0xCB0ED6FF},
{0xCB0EE700,0xCB0EE7FF},
{0xCB0EF600,0xCB0EF6FF},
{0xCB0F0000,0xCB0F0FFF},
{0xCB0F1400,0xCB0F16FF},
{0xCB0F5700,0xCB0F59FF},
{0xCB0F6900,0xCB0F69FF},
{0xCB0F7000,0xCB0F77FF},
{0xCB0F8200,0xCB0F83FF},
{0xCB0F9500,0xCB0F95FF},
{0xCB0F9700,0xCB0F97FF},
{0xCB0F9C00,0xCB0F9FFF},
{0xCB0FAE00,0xCB0FAEFF},
{0xCB0FE300,0xCB0FE3FF},
{0xCB0FE800,0xCB0FF1FF},
{0xCB0FF600,0xCB0FF6FF},
{0xCB100A00,0xCB100AFF},
{0xCB100C00,0xCB100DFF},
{0xCB101000,0xCB1017FF},
{0xCB101B00,0xCB101BFF},
{0xCB102600,0xCB1026FF},
{0xCB103100,0xCB1033FF},
{0xCB103A00,0xCB103AFF},
{0xCB108500,0xCB1085FF},
{0xCB10A100,0xCB10A2FF},
{0xCB10BA00,0xCB10BBFF},
{0xCB10E400,0xCB10E4FF},
{0xCB10EE00,0xCB10EEFF},
{0xCB10F000,0xCB10F0FF},
{0xCB10F500,0xCB10F5FF},
{0xCB110200,0xCB1102FF},
{0xCB111200,0xCB1112FF},
{0xCB111C00,0xCB111CFF},
{0xCB112700,0xCB1127FF},
{0xCB113800,0xCB1138FF},
{0xCB114A00,0xCB114BFF},
{0xCB115800,0xCB1159FF},
{0xCB118800,0xCB1188FF},
{0xCB11A400,0xCB11A4FF},
{0xCB11BB00,0xCB11BBFF},
{0xCB11BE00,0xCB11BFFF},
{0xCB11E700,0xCB11E7FF},
{0xCB11E900,0xCB11E9FF},
{0xCB11F800,0xCB11F8FF},
{0xCB11FF00,0xCB11FFFF},
{0xCB120200,0xCB1204FF},
{0xCB120700,0xCB1207FF},
{0xCB121F00,0xCB121FFF},
{0xCB122500,0xCB1225FF},
{0xCB123000,0xCB1232FF},
{0xCB123400,0xCB1234FF},
{0xCB124800,0xCB124BFF},
{0xCB125000,0xCB1251FF},
{0xCB125700,0xCB1257FF},
{0xCB126400,0xCB1265FF},
{0xCB126900,0xCB1269FF},
{0xCB126B00,0xCB126BFF},
{0xCB126E00,0xCB126EFF},
{0xCB128100,0xCB1281FF},
{0xCB128300,0xCB1285FF},
{0xCB129000,0xCB1290FF},
{0xCB129900,0xCB1299FF},
{0xCB12C700,0xCB12C7FF},
{0xCB12D000,0xCB12D0FF},
{0xCB12D300,0xCB12D3FF},
{0xCB12D700,0xCB12D7FF},
{0xCB131200,0xCB1312FF},
{0xCB131800,0xCB1318FF},
{0xCB131E00,0xCB131EFF},
{0xCB132000,0xCB1327FF},
{0xCB132900,0xCB1329FF},
{0xCB132C00,0xCB132EFF},
{0xCB133A00,0xCB133AFF},
{0xCB133C00,0xCB133DFF},
{0xCB134000,0xCB1340FF},
{0xCB134400,0xCB1344FF},
{0xCB134800,0xCB1348FF},
{0xCB136500,0xCB1365FF},
{0xCB136F00,0xCB136FFF},
{0xCB138300,0xCB1383FF},
{0xCB138500,0xCB1385FF},
{0xCB139000,0xCB1390FF},
{0xCB139500,0xCB1395FF},
{0xCB139C00,0xCB139CFF},
{0xCB13B000,0xCB13B0FF},
{0xCB13B200,0xCB13B3FF},
{0xCB13D000,0xCB13D0FF},
{0xCB13E400,0xCB13E7FF},
{0xCB13E900,0xCB13E9FF},
{0xCB13F200,0xCB13F2FF},
{0xCB13F800,0xCB13F9FF},
{0xCB13FF00,0xCB13FFFF},
{0xCB141100,0xCB1411FF},
{0xCB142800,0xCB1429FF},
{0xCB143000,0xCB1430FF},
{0xCB143D00,0xCB143DFF},
{0xCB144100,0xCB1441FF},
{0xCB145400,0xCB1455FF},
{0xCB145900,0xCB1459FF},
{0xCB146A00,0xCB146BFF},
{0xCB147300,0xCB1473FF},
{0xCB147500,0xCB1477FF},
{0xCB147A00,0xCB147AFF},
{0xCB147E00,0xCB147FFF},
{0xCB148700,0xCB148FFF},
{0xCB149600,0xCB1496FF},
{0xCB14E600,0xCB14E6FF},
{0xCB14E800,0xCB14E8FF},
{0xCB14EC00,0xCB14ECFF},
{0xCB150000,0xCB1502FF},
{0xCB150800,0xCB1508FF},
{0xCB150A00,0xCB150AFF},
{0xCB151200,0xCB1512FF},
{0xCB152100,0xCB1522FF},
{0xCB152900,0xCB1529FF},
{0xCB152C00,0xCB152CFF},
{0xCB154400,0xCB1544FF},
{0xCB155200,0xCB1552FF},
{0xCB156000,0xCB1563FF},
{0xCB157C00,0xCB157CFF},
{0xCB158800,0xCB1589FF},
{0xCB159100,0xCB1591FF},
{0xCB15CE00,0xCB15CEFF},
{0xCB161800,0xCB1618FF},
{0xCB161C00,0xCB161DFF},
{0xCB161F00,0xCB161FFF},
{0xCB164400,0xCB1644FF},
{0xCB164C00,0xCB164CFF},
{0xCB164E00,0xCB164EFF},
{0xCB165400,0xCB1654FF},
{0xCB165700,0xCB1657FF},
{0xCB165C00,0xCB165FFF},
{0xCB166300,0xCB1663FF},
{0xCB166A00,0xCB166AFF},
{0xCB167A00,0xCB167BFF},
{0xCB168300,0xCB1683FF},
{0xCB16A300,0xCB16A3FF},
{0xCB16A600,0xCB16A6FF},
{0xCB16AA00,0xCB16AAFF},
{0xCB16B000,0xCB16B7FF},
{0xCB16C200,0xCB16C2FF},
{0xCB16F200,0xCB16F3FF},
{0xCB16F500,0xCB16F6FF},
{0xCB16FC00,0xCB16FDFF},
{0xCB170000,0xCB1700FF},
{0xCB172F00,0xCB172FFF},
{0xCB173D00,0xCB173FFF},
{0xCB174900,0xCB1749FF},
{0xCB175500,0xCB1755FF},
{0xCB175C00,0xCB175FFF},
{0xCB176200,0xCB1762FF},
{0xCB176B00,0xCB176BFF},
{0xCB177000,0xCB1770FF},
{0xCB178200,0xCB1782FF},
{0xCB178C00,0xCB178DFF},
{0xCB17AC00,0xCB17ACFF},
{0xCB17B600,0xCB17B6FF},
{0xCB17BA00,0xCB17BBFF},
{0xCB17C000,0xCB17C0FF},
{0xCB17C500,0xCB17C6FF},
{0xCB17CC00,0xCB17CFFF},
{0xCB17E000,0xCB17E0FF},
{0xCB17E400,0xCB17E7FF},
{0xCB17F900,0xCB17F9FF},
{0xCB17FB00,0xCB17FBFF},
{0xCB180D00,0xCB180DFF},
{0xCB181200,0xCB1812FF},
{0xCB181B00,0xCB181BFF},
{0xCB182B00,0xCB182BFF},
{0xCB183800,0xCB1838FF},
{0xCB183A00,0xCB183AFF},
{0xCB184300,0xCB1843FF},
{0xCB184A00,0xCB184AFF},
{0xCB184F00,0xCB1851FF},
{0xCB185400,0xCB1856FF},
{0xCB185A00,0xCB185AFF},
{0xCB186F00,0xCB1870FF},
{0xCB187400,0xCB1874FF},
{0xCB187A00,0xCB187BFF},
{0xCB189100,0xCB1891FF},
{0xCB189800,0xCB1899FF},
{0xCB189D00,0xCB189DFF},
{0xCB18A100,0xCB18A1FF},
{0xCB18A700,0xCB18A7FF},
{0xCB18BA00,0xCB18BBFF},
{0xCB18C700,0xCB18C7FF},
{0xCB18CA00,0xCB18CAFF},
{0xCB18D400,0xCB18D5FF},
{0xCB18D900,0xCB18D9FF},
{0xCB18DB00,0xCB18DBFF},
{0xCB18F400,0xCB18F4FF},
{0xCB191300,0xCB1915FF},
{0xCB192E00,0xCB192EFF},
{0xCB193000,0xCB1937FF},
{0xCB194000,0xCB1941FF},
{0xCB195B00,0xCB195BFF},
{0xCB196300,0xCB1964FF},
{0xCB196A00,0xCB196AFF},
{0xCB198300,0xCB1983FF},
{0xCB198700,0xCB1987FF},
{0xCB198A00,0xCB198AFF},
{0xCB199300,0xCB1993FF},
{0xCB199900,0xCB199BFF},
{0xCB19A400,0xCB19A4FF},
{0xCB19A600,0xCB19A6FF},
{0xCB19AE00,0xCB19AFFF},
{0xCB19B400,0xCB19B4FF},
{0xCB19B600,0xCB19B6FF},
{0xCB19BF00,0xCB19BFFF},
{0xCB19C700,0xCB19C8FF},
{0xCB19CA00,0xCB19CBFF},
{0xCB19D000,0xCB19DFFF},
{0xCB19E500,0xCB19E5FF},
{0xCB19EB00,0xCB19ECFF},
{0xCB19F200,0xCB19F2FF},
{0xCB1A0C00,0xCB1A0CFF},
{0xCB1A2200,0xCB1A22FF},
{0xCB1A3100,0xCB1A32FF},
{0xCB1A3700,0xCB1A39FF},
{0xCB1A3C00,0xCB1A3CFF},
{0xCB1A4100,0xCB1A41FF},
{0xCB1A4400,0xCB1A44FF},
{0xCB1A4C00,0xCB1A4CFF},
{0xCB1A5000,0xCB1A50FF},
{0xCB1A5400,0xCB1A54FF},
{0xCB1A6100,0xCB1A61FF},
{0xCB1A6600,0xCB1A67FF},
{0xCB1A7300,0xCB1A74FF},
{0xCB1A8100,0xCB1A81FF},
{0xCB1A8F00,0xCB1A90FF},
{0xCB1A9400,0xCB1A95FF},
{0xCB1A9A00,0xCB1A9AFF},
{0xCB1A9E00,0xCB1A9FFF},
{0xCB1AAA00,0xCB1AAAFF},
{0xCB1AAD00,0xCB1AADFF},
{0xCB1AB000,0xCB1AB0FF},
{0xCB1AB900,0xCB1AB9FF},
{0xCB1ACA00,0xCB1ACBFF},
{0xCB1AD200,0xCB1AD2FF},
{0xCB1AD600,0xCB1AD6FF},
{0xCB1ADE00,0xCB1ADEFF},
{0xCB1AE000,0xCB1AE0FF},
{0xCB1AE400,0xCB1AE4FF},
{0xCB1AE800,0xCB1AE8FF},
{0xCB1B0000,0xCB1B00FF},
{0xCB1B0A00,0xCB1B0AFF},
{0xCB1B0F00,0xCB1B10FF},
{0xCB1B1400,0xCB1B14FF},
{0xCB1B1600,0xCB1B17FF},
{0xCB1B2800,0xCB1B28FF},
{0xCB1B2D00,0xCB1B2DFF},
{0xCB1B3500,0xCB1B35FF},
{0xCB1B4100,0xCB1B42FF},
{0xCB1B5100,0xCB1B51FF},
{0xCB1B5800,0xCB1B58FF},
{0xCB1B6600,0xCB1B66FF},
{0xCB1B6D00,0xCB1B6DFF},
{0xCB1B7500,0xCB1B75FF},
{0xCB1B7900,0xCB1B7BFF},
{0xCB1B7D00,0xCB1B7DFF},
{0xCB1BC800,0xCB1BC8FF},
{0xCB1BCA00,0xCB1BCAFF},
{0xCB1BE900,0xCB1BE9FF},
{0xCB1BF100,0xCB1BF1FF},
{0xCB1BFA00,0xCB1BFAFF},
{0xCB1C0A00,0xCB1C0AFF},
{0xCB1C0C00,0xCB1C0CFF},
{0xCB1C2100,0xCB1C23FF},
{0xCB1C2B00,0xCB1C2CFF},
{0xCB1C3600,0xCB1C36FF},
{0xCB1C3800,0xCB1C38FF},
{0xCB1C4900,0xCB1C4AFF},
{0xCB1C4C00,0xCB1C4CFF},
{0xCB1C5600,0xCB1C56FF},
{0xCB1C5800,0xCB1C58FF},
{0xCB1C7000,0xCB1C70FF},
{0xCB1C8300,0xCB1C83FF},
{0xCB1C8800,0xCB1C88FF},
{0xCB1C8C00,0xCB1C8CFF},
{0xCB1C9100,0xCB1C91FF},
{0xCB1CA500,0xCB1CA5FF},
{0xCB1CA900,0xCB1CAAFF},
{0xCB1CB200,0xCB1CB3FF},
{0xCB1CB900,0xCB1CB9FF},
{0xCB1CBB00,0xCB1CBBFF},
{0xCB1CC400,0xCB1CC4FF},
{0xCB1CE200,0xCB1CE3FF},
{0xCB1CEF00,0xCB1CEFFF},
{0xCB1D0200,0xCB1D02FF},
{0xCB1D0800,0xCB1D09FF},
{0xCB1D0D00,0xCB1D0EFF},
{0xCB1D1C00,0xCB1D1CFF},
{0xCB1D2E00,0xCB1D2EFF},
{0xCB1D3900,0xCB1D39FF},
{0xCB1D3D00,0xCB1D3DFF},
{0xCB1D3F00,0xCB1D3FFF},
{0xCB1D4500,0xCB1D45FF},
{0xCB1D4900,0xCB1D49FF},
{0xCB1D5100,0xCB1D51FF},
{0xCB1D5A00,0xCB1D5AFF},
{0xCB1D5F00,0xCB1D5FFF},
{0xCB1D6400,0xCB1D64FF},
{0xCB1D6700,0xCB1D67FF},
{0xCB1D7000,0xCB1D70FF},
{0xCB1D7800,0xCB1D7BFF},
{0xCB1DB600,0xCB1DB7FF},
{0xCB1DBB00,0xCB1DBBFF},
{0xCB1DBD00,0xCB1DBEFF},
{0xCB1DCD00,0xCB1DCDFF},
{0xCB1DD200,0xCB1DD2FF},
{0xCB1DD900,0xCB1DD9FF},
{0xCB1DE300,0xCB1DE3FF},
{0xCB1DE700,0xCB1DE7FF},
{0xCB1DE900,0xCB1DEAFF},
{0xCB1DF800,0xCB1DF8FF},
{0xCB1DFE00,0xCB1DFFFF},
{0xCB1E1000,0xCB1E11FF},
{0xCB1E1900,0xCB1E19FF},
{0xCB1E1B00,0xCB1E1BFF},
{0xCB1E1D00,0xCB1E1DFF},
{0xCB1E4200,0xCB1E42FF},
{0xCB1E5100,0xCB1E51FF},
{0xCB1E5700,0xCB1E57FF},
{0xCB1E6F00,0xCB1E6FFF},
{0xCB1E7900,0xCB1E79FF},
{0xCB1E7B00,0xCB1E7BFF},
{0xCB1E9800,0xCB1E98FF},
{0xCB1E9C00,0xCB1E9CFF},
{0xCB1EA200,0xCB1EA2FF},
{0xCB1EAD00,0xCB1EADFF},
{0xCB1EAF00,0xCB1EAFFF},
{0xCB1EBB00,0xCB1EBBFF},
{0xCB1EC200,0xCB1EC2FF},
{0xCB1ED900,0xCB1ED9FF},
{0xCB1EDC00,0xCB1EDCFF},
{0xCB1EDE00,0xCB1EDEFF},
{0xCB1EE800,0xCB1EE9FF},
{0xCB1EEB00,0xCB1EEBFF},
{0xCB1EF000,0xCB1EF1FF},
{0xCB1EF600,0xCB1EF6FF},
{0xCB1EFA00,0xCB1EFBFF},
{0xCB1F2D00,0xCB1F2EFF},
{0xCB1F3100,0xCB1F31FF},
{0xCB1F3300,0xCB1F33FF},
{0xCB1F3600,0xCB1F37FF},
{0xCB1F4500,0xCB1F45FF},
{0xCB1F4800,0xCB1F48FF},
{0xCB1F5000,0xCB1F50FF},
{0xCB1F5500,0xCB1F55FF},
{0xCB1F6100,0xCB1F61FF},
{0xCB1F6900,0xCB1F6AFF},
{0xCB1F6C00,0xCB1F6DFF},
{0xCB1F7C00,0xCB1F7CFF},
{0xCB1FA200,0xCB1FA2FF},
{0xCB1FAE00,0xCB1FAEFF},
{0xCB1FB100,0xCB1FB1FF},
{0xCB1FB500,0xCB1FB5FF},
{0xCB1FBB00,0xCB1FBBFF},
{0xCB1FBD00,0xCB1FBDFF},
{0xCB1FCC00,0xCB1FCCFF},
{0xCB1FDC00,0xCB1FDCFF},
{0xCB1FDE00,0xCB1FDFFF},
{0xCB1FE100,0xCB1FE1FF},
{0xCB1FE500,0xCB1FE5FF},
{0xCB1FF800,0xCB1FF9FF},
{0xCB1FFD00,0xCB1FFDFF},
{0xCB201400,0xCB2014FF},
{0xCB203000,0xCB2031FF},
{0xCB203800,0xCB2038FF},
{0xCB203C00,0xCB203CFF},
{0xCB203E00,0xCB203EFF},
{0xCB204400,0xCB2045FF},
{0xCB204C00,0xCB204CFF},
{0xCB205100,0xCB2051FF},
{0xCB205400,0xCB2055FF},
{0xCB205F00,0xCB205FFF},
{0xCB206600,0xCB2066FF},
{0xCB206900,0xCB2069FF},
{0xCB208200,0xCB2082FF},
{0xCB208500,0xCB2085FF},
{0xCB208C00,0xCB208CFF},
{0xCB209800,0xCB2098FF},
{0xCB20BA00,0xCB20BBFF},
{0xCB20C000,0xCB20C0FF},
{0xCB20C400,0xCB20C4FF},
{0xCB20CB00,0xCB20CDFF},
{0xCB20D400,0xCB20D4FF},
{0xCB210400,0xCB2104FF},
{0xCB210700,0xCB210FFF},
{0xCB211500,0xCB2115FF},
{0xCB211A00,0xCB211AFF},
{0xCB212000,0xCB2120FF},
{0xCB213F00,0xCB2140FF},
{0xCB214300,0xCB2144FF},
{0xCB214900,0xCB2149FF},
{0xCB214F00,0xCB214FFF},
{0xCB216400,0xCB2164FF},
{0xCB217A00,0xCB217AFF},
{0xCB218100,0xCB2181FF},
{0xCB218300,0xCB2183FF},
{0xCB219100,0xCB2191FF},
{0xCB219C00,0xCB219CFF},
{0xCB219E00,0xCB219FFF},
{0xCB21AE00,0xCB21AEFF},
{0xCB21B900,0xCB21B9FF},
{0xCB21C800,0xCB21C8FF},
{0xCB21CA00,0xCB21CCFF},
{0xCB21CE00,0xCB21CFFF},
{0xCB21D600,0xCB21D7FF},
{0xCB21E000,0xCB21E2FF},
{0xCB21E900,0xCB21E9FF},
{0xCB21F300,0xCB21F3FF},
{0xCB21FA00,0xCB21FAFF},
{0xCB220400,0xCB2204FF},
{0xCB221500,0xCB2215FF},
{0xCB221B00,0xCB221BFF},
{0xCB222700,0xCB2227FF},
{0xCB223000,0xCB2231FF},
{0xCB223600,0xCB2236FF},
{0xCB223800,0xCB2239FF},
{0xCB224300,0xCB2243FF},
{0xCB224500,0xCB2245FF},
{0xCB224C00,0xCB224CFF},
{0xCB225C00,0xCB225CFF},
{0xCB226A00,0xCB226AFF},
{0xCB227100,0xCB2271FF},
{0xCB229300,0xCB2293FF},
{0xCB229600,0xCB2296FF},
{0xCB229800,0xCB2299FF},
{0xCB22A100,0xCB22A2FF},
{0xCB22BB00,0xCB22BBFF},
{0xCB22C000,0xCB22C7FF},
{0xCB22CC00,0xCB22CFFF},
{0xCB22E800,0xCB22E8FF},
{0xCB22F000,0xCB22F0FF},
{0xCB22F200,0xCB22F2FF},
{0xCB22F500,0xCB22F5FF},
{0xCB22FB00,0xCB22FBFF},
{0xCB370200,0xCB3704FF},
{0xCB370A00,0xCB370AFF},
{0xCB370D00,0xCB370DFF},
{0xCB371600,0xCB3716FF},
{0xCB371E00,0xCB371EFF},
{0xCB375D00,0xCB375DFF},
{0xCB376500,0xCB3765FF},
{0xCB376D00,0xCB376EFF},
{0xCB377400,0xCB3775FF},
{0xCB377700,0xCB3777FF},
{0xCB378000,0xCB3781FF},
{0xCB379200,0xCB3793FF},
{0xCB37C000,0xCB37C0FF},
{0xCB37C400,0xCB37C4FF},
{0xCB37DA00,0xCB37DBFF},
{0xCB37DD00,0xCB37DDFF},
{0xCB37E000,0xCB37E0FF},
{0xCB380100,0xCB3801FF},
{0xCB380400,0xCB3804FF},
{0xCB380C00,0xCB380CFF},
{0xCB381800,0xCB3818FF},
{0xCB382600,0xCB3826FF},
{0xCB382800,0xCB3828FF},
{0xCB382E00,0xCB382EFF},
{0xCB383000,0xCB3837FF},
{0xCB384400,0xCB3845FF},
{0xCB385200,0xCB3855FF},
{0xCB385F00,0xCB385FFF},
{0xCB386E00,0xCB386EFF},
{0xCB387900,0xCB3879FF},
{0xCB38A100,0xCB38A1FF},
{0xCB38A900,0xCB38A9FF},
{0xCB38AC00,0xCB38ADFF},
{0xCB38AF00,0xCB38AFFF},
{0xCB38B700,0xCB38B7FF},
{0xCB38B900,0xCB38B9FF},
{0xCB38BB00,0xCB38BBFF},
{0xCB38C000,0xCB38C0FF},
{0xCB38C600,0xCB38C6FF},
{0xCB38C900,0xCB38C9FF},
{0xCB38D000,0xCB38D2FF},
{0xCB38D600,0xCB38D6FF},
{0xCB38D800,0xCB38D8FF},
{0xCB38E300,0xCB38E4FF},
{0xCB38E800,0xCB38E8FF},
{0xCB38F000,0xCB38F0FF},
{0xCB38FC00,0xCB38FCFF},
{0xCB38FE00,0xCB38FEFF},
{0xCB390500,0xCB3906FF},
{0xCB390C00,0xCB390DFF},
{0xCB391C00,0xCB391CFF},
{0xCB392700,0xCB3927FF},
{0xCB392E00,0xCB392EFF},
{0xCB393A00,0xCB393AFF},
{0xCB393D00,0xCB393DFF},
{0xCB394200,0xCB3942FF},
{0xCB394500,0xCB3947FF},
{0xCB394900,0xCB3949FF},
{0xCB395A00,0xCB395AFF},
{0xCB396500,0xCB3965FF},
{0xCB396D00,0xCB396DFF},
{0xCB397B00,0xCB397BFF},
{0xCB399D00,0xCB399DFF},
{0xCB39C800,0xCB39C8FF},
{0xCB39CA00,0xCB39CAFF},
{0xCB39CE00,0xCB39CEFF},
{0xCB39DE00,0xCB39DEFF},
{0xCB39E000,0xCB39EFFF},
{0xCB39F600,0xCB39F7FF},
{0xCB39F900,0xCB39F9FF},
{0xCB39FD00,0xCB39FFFF},
{0xCB3E0200,0xCB3E02FF},
{0xCB3E8300,0xCB3E83FF},
{0xCB3E8B00,0xCB3E8BFF},
{0xCB3EA100,0xCB3EA1FF},
{0xCB3EC500,0xCB3EC5FF},
{0xCB3EE400,0xCB3EE7FF},
{0xCB3EEA00,0xCB3EEAFF},
{0xCB3EF600,0xCB3EF6FF},
{0xCB4CA000,0xCB4CA3FF},
{0xCB4CA800,0xCB4CABFF},
{0xCB4DB400,0xCB4DB7FF},
{0xCB4E3000,0xCB4E3FFF},
{0xCB4F0000,0xCB4F0FFF},
{0xCB500400,0xCB5005FF},
{0xCB502000,0xCB502FFF},
{0xCB503900,0xCB5039FF},
{0xCB508400,0xCB509FFF},
{0xCB510000,0xCB5107FF},
{0xCB511000,0xCB511FFF},
{0xCB520000,0xCB5201FF},
{0xCB521000,0xCB5217FF},
{0xCB530000,0xCB5303FF},
{0xCB533800,0xCB533FFF},
{0xCB53E000,0xCB53EFFF},
{0xCB560000,0xCB567FFF},
{0xCB56FE00,0xCB56FFFF},
{0xCB582000,0xCB583FFF},
{0xCB58C000,0xCB58DFFF},
{0xCB590000,0xCB5903FF},
{0xCB590800,0xCB590FFF},
{0xCB598800,0xCB598BFF},
{0xCB5A0000,0xCB5A03FF},
{0xCB5A0800,0xCB5A0BFF},
{0xCB5A8000,0xCB5ADFFF},
{0xCB5B2000,0xCB5B3FFF},
{0xCB5B6000,0xCB5B6FFF},
{0xCB5B7800,0xCB5B7FFF},
{0xCB5C0000,0xCB5C03FF},
{0xCB5CA000,0xCB5CBFFF},
{0xCB5D0000,0xCB5E1FFF},
{0xCB5F0000,0xCB5F07FF},
{0xCB5F6000,0xCB5FFFFF},
{0xCB630800,0xCB631FFF},
{0xCB635000,0xCB635FFF},
{0xCB642000,0xCB6437FF},
{0xCB643F00,0xCB643FFF},
{0xCB645000,0xCB647FFF},
{0xCB64C000,0xCB64CFFF},
{0xCB682000,0xCB682FFF},
{0xCB696000,0xCB699FFF},
{0xCB6B0000,0xCB6B7FFF},
{0xCB6EA000,0xCB6EBFFF},
{0xCB6ED000,0xCB6EDFFF},
{0xCB6EE800,0xCB6EEAFF},
{0xCB72F400,0xCB72F7FF},
{0xCB76C000,0xCB76DFFF},
{0xCB76F100,0xCB76F1FF},
{0xCB76F800,0xCB76FBFF},
{0xCB771800,0xCB7723FF},
{0xCB775000,0xCB7753FF},
{0xCB775500,0xCB7755FF},
{0xCB777100,0xCB77FFFF},
{0xCB802000,0xCB803FFF},
{0xCB806000,0xCB807FFF},
{0xCB80E000,0xCB80E7FF},
{0xCB810800,0xCB810FFF},
{0xCB822000,0xCB823FFF},
{0xCB842000,0xCB843FFF},
{0xCB86F000,0xCB86F7FF},
{0xCB876000,0xCB877FFF},
{0xCB87A000,0xCB87AFFF},
{0xCB8E0C00,0xCB8E0C7F},
{0xCB8EE000,0xCB8EFFFF},
{0xCB906000,0xCB907FFF},
{0xCB910000,0xCB911FFF},
{0xCB940000,0xCB9453FF},
{0xCB945600,0xCB9457FF},
{0xCB955C00,0xCB955FFF},
{0xCB984000,0xCB985FFF},
{0xCB988000,0xCB989FFF},
{0xCB990000,0xCB9903FF},
{0xCB9CC000,0xCB9CFFFF},
{0xCB9E1000,0xCB9E17FF},
{0xCBA06800,0xCBA06FFF},
{0xCBA08100,0xCBA081FF},
{0xCBA0C000,0xCBA0DFFF},
{0xCBA10000,0xCBA103FF},
{0xCBA1B400,0xCBA1B4FF},
{0xCBA1C000,0xCBA1DFFF},
{0xCBA6A000,0xCBA6BFFF},
{0xCBA80000,0xCBA81FFF},
{0xCBAA3A00,0xCBAA3BFF},
{0xCBAB0000,0xCBAB03FF},
{0xCBABE000,0xCBABEFFF},
{0xCBAE0400,0xCBAE04FF},
{0xCBAE0700,0xCBAE07FF},
{0xCBAE6000,0xCBAE7FFF},
{0xCBAF8000,0xCBAF9FFF},
{0xCBAFC000,0xCBB05FFF},
{0xCBB0A800,0xCBB0AFFF},
{0xCBB85000,0xCBB85FFF},
{0xCBBBA000,0xCBBBBFFF},
{0xCBBD0000,0xCBBD01FF},
{0xCBBD0600,0xCBBD07FF},
{0xCBBD7000,0xCBBD73FF},
{0xCBBDC000,0xCBBDDFFF},
{0xCBBE6000,0xCBBE6FFF},
{0xCBBEF900,0xCBBEF9FF},
{0xCBBF0000,0xCBBF01FF},
{0xCBBF1000,0xCBBF1FFF},
{0xCBBF4000,0xCBBF7FFF},
{0xCBBF9000,0xCBBF9FFF},
{0xCBC00000,0xCBC01FFF},
{0xCBC1513C,0xCBC1513F},
{0xCBC1E000,0xCBC1FFFF},
{0xCBC27800,0xCBC27FFF},
{0xCBC34000,0xCBC35FFF},
{0xCBC37000,0xCBC377FF},
{0xCBC38000,0xCBC40FFF},
{0xCBCAEC00,0xCBCAEFFF},
{0xCBCD4000,0xCBCD5FFF},
{0xCBCD8000,0xCBCDFFFF},
{0xCBCF4000,0xCBD013FF},
{0xCBD02000,0xCBD03FFF},
{0xCBD1E000,0xCBD1FFFF},
{0xCBD40000,0xCBD40FFF},
{0xCBD45000,0xCBD45FFF},
{0xCBD79200,0xCBD792FF},
{0xCBD7E800,0xCBD7EFFF},
{0xCBDEC000,0xCBDEC5FF},
{0xCBDEC700,0xCBDEC9FF},
{0xCBDECB00,0xCBDECFFF},
{0xCBDF1000,0xCBDF17FF},
{0xCC459600,0xCC4596FF},
{0xCE493C60,0xCE493C7F},
{0xCE494480,0xCE49449F},
{0xCE495B20,0xCE495B5F},
{0xCE49C340,0xCE49C35F},
{0xCE49D260,0xCE49D27F},
{0xCE49E340,0xCE49E37F},
{0xCE49E418,0xCE49E41F},
{0xCE49F620,0xCE49F62F},
{0xCE6BFE48,0xCE6BFE4F},
{0xCE7DAE10,0xCE7DAE17},
{0xCEA875A0,0xCEA875AF},
{0xCEB6C7D0,0xCEB6C7D7},
{0xCEB6C880,0xCEB6C8BF},
{0xCEB6DD70,0xCEB6DD7F},
{0xCEB6DDC0,0xCEB6DDFF},
{0xCED6D01D,0xCED6D020},
{0xCED6D2CF,0xCED6D2D2},
{0xCED6D347,0xCED6D34A},
{0xCED6D3D8,0xCED6D3DB},
{0xCED6D64D,0xCED6D650},
{0xCED6D70C,0xCED6D70F},
{0xCED6D755,0xCED6D758},
{0xCEDDD9E8,0xCEDDD9EB},
{0xCEDDDA20,0xCEDDDA27},
{0xCEDDDC08,0xCEDDDC0F},
{0xCEDDDD40,0xCEDDDD47},
{0xCEDDDDB0,0xCEDDDDB7},
{0xCEDDDED0,0xCEDDDED7},
{0xCEDE1A20,0xCEDE1A27},
{0xCF75A500,0xCF75A5FF},
{0xCFD1CE80,0xCFD1CEFF},
{0xCFD1E220,0xCFD1E22F},
{0xCFFEB200,0xCFFEB27F},
{0xCFFEB300,0xCFFEB37F},
{0xCFFEB400,0xCFFEB830},
{0xCFFEB900,0xCFFEBCFF},
{0xD04AAF01,0xD04AAF1F},
{0xD04F5A60,0xD04F5A67},
{0xD0738C00,0xD0738CFF},
{0xD15D6E00,0xD15D6E7F},
{0xD15D7080,0xD15D70FF},
{0xD15D7280,0xD15D72BF},
{0xD15DB200,0xD15DB2A0},
{0xD15DB8C0,0xD15DB8FF},
{0xD15DBD00,0xD15DBFFF},
{0xD15DC240,0xD15DC27F},
{0xD15DEC68,0xD15DEC6F},
{0xD15DF080,0xD15DF0FF},
{0xD1BE1868,0xD1BE186F},
{0xD2020000,0xD2021FFF},
{0xD2050000,0xD2051FFF},
{0xD2053800,0xD2053FFF},
{0xD2058000,0xD2059FFF},
{0xD2078900,0xD2078BFF},
{0xD20C0000,0xD20DFFFF},
{0xD20E4000,0xD20E5FFF},
{0xD20E7000,0xD20FBFFF},
{0xD2108000,0xD210BFFF},
{0xD2150000,0xD216FFFF},
{0xD2172000,0xD2173FFF},
{0xD2190000,0xD22FFFFF},
{0xD2308800,0xD2308FFF},
{0xD2330000,0xD2346CFF},
{0xD2346E00,0xD235FFFF},
{0xD238C000,0xD238DFFF},
{0xD2480000,0xD24EFFFF},
{0xD24F4000,0xD24F7FFF},
{0xD24FE000,0xD24FFFFF},
{0xD2520000,0xD253FFFF},
{0xD2578000,0xD257BFFF},
{0xD2B9C000,0xD2B9FFFF},
{0xD2C06000,0xD2C07FFF},
{0xD3400000,0xD347FFFF},
{0xD3500000,0xD367FFFF},
{0xD3880000,0xD3A7FFFF},
{0xD43FB51C,0xD43FB51F},
{0xD43FB528,0xD43FB52F},
{0xD43FB54C,0xD43FB54F},
{0xD43FB58C,0xD43FB58F},
{0xD43FB5B4,0xD43FB5BB},
{0xD43FB5C8,0xD43FB5CB},
{0xD43FB5E0,0xD43FB5E3},
{0xD43FB704,0xD43FB704},
{0xD43FB709,0xD43FB70A},
{0xD43FB70F,0xD43FB70F},
{0xD43FB713,0xD43FB713},
{0xD43FB717,0xD43FB717},
{0xD43FB71C,0xD43FB71C},
{0xD43FB73A,0xD43FB73A},
{0xD43FB73E,0xD43FB73E},
{0xD43FB740,0xD43FB740},
{0xD43FB744,0xD43FB744},
{0xD43FB7D4,0xD43FB7DB},
{0xD43FB7E4,0xD43FB7E7},
{0xD80FEEA0,0xD80FEEBF},
{0xD8263390,0xD8263393},
{0xD85E6900,0xD85E69FF},
{0xD85E7480,0xD85E74FF},
{0xD86CE4E4,0xD86CE4EB},
{0xD86CE580,0xD86CE58F},
{0xD86CE7D0,0xD86CE7DF},
{0xD86CEA6C,0xD86CEA7B},
{0xD86CECD8,0xD86CECE7},
{0xD8778A20,0xD8778A27},
{0xD8888880,0xD888888F},
{0xD888A2D0,0xD888A2DF},
{0xD888B7B8,0xD888B7BF},
{0xD888D9B0,0xD888D9BF},
{0xD88BB750,0xD88BB757},
{0xD8970710,0xD897071F},
{0xD89E8F41,0xD89E8F80},
{0xD89E9301,0xD89E93FF},
{0xD8C6D340,0xD8C6D37F},
{0xD8DAA810,0xD8DAA81F},
{0xD8DAD6E0,0xD8DAD6E7},
{0xD9078D00,0xD9078D27},
{0xD9078D30,0xD9078F00},
{0xD9086500,0xD90865FF},
{0xD9ACB990,0xD9ACB990},
{0xD9ACB9D7,0xD9ACB9D7},
{0xD9ACB9D9,0xD9ACB9E2},
{0xD9ACB9E6,0xD9ACB9E6},
{0xD9ACB9E8,0xD9ACB9E8},
{0xD9ACB9EB,0xD9ACB9ED},
{0xD9ACB9EF,0xD9ACB9F0},
{0xDA000000,0xDA1FFFFF},
{0xDA380000,0xDA63FFFF},
{0xDA645800,0xDA64FFFF},
{0xDA680000,0xDA6DFFFF},
{0xDAB9C000,0xDAB9DFFF},
{0xDAB9F000,0xDAB9F7FF},
{0xDAC00000,0xDACFFFFF},
{0xDAF00000,0xDAF7FFFF},
{0xDAF90000,0xDAF9FFFF},
{0xDB480000,0xDB48FFFF},
{0xDB520000,0xDB52FFFF},
{0xDB538000,0xDB53FFFF},
{0xDB800000,0xDB9FFFFF},
{0xDBD80000,0xDBEFFFFF},
{0xDBF20000,0xDBF7FFFF},
{0xDC65C000,0xDC65FFFF},
{0xDC700000,0xDC73FFFF},
{0xDC988000,0xDC98FFFF},
{0xDC9A0000,0xDC9BFFFF},
{0xDCA00000,0xDCCFFFFF},
{0xDCE70000,0xDCE73FFF},
{0xDCE78000,0xDCE7FFFF},
{0xDCE84000,0xDCE87FFF},
{0xDCEA0000,0xDCEAFFFF},
{0xDCF20000,0xDCF3FFFF},
{0xDCF78800,0xDCF78FFF},
{0xDCF80000,0xDCFCFFFF},
{0xDD000000,0xDD0CBFFF},
{0xDD0D0000,0xDD0FFFFF},
{0xDD7A0000,0xDD7BFFFF},
{0xDD808000,0xDD83FFFF},
{0xDD85E000,0xDD85FFFF},
{0xDD880000,0xDD89FFFF},
{0xDDAC0000,0xDDB7FFFF},
{0xDDC00000,0xDDC7CFFF},
{0xDDC7E000,0xDDEFFFFF},
{0xDE100000,0xDE5FFFFF},
{0xDE7D0000,0xDE7DFFFF},
{0xDE7E8000,0xDE7EFFFF},
{0xDE800000,0xDE8FFFFF},
{0xDEA00000,0xDEA3FFFF},
{0xDEA80000,0xDEDFFFFF},
{0xDEF00000,0xDEF9FFFF},
{0xDF000000,0xDF0FFFFF},
{0xDF140000,0xDF15FFFF},
{0xDF1BB800,0xDF1BBBFF},
{0xDF400000,0xDF75FFFF},
{0xDF780000,0xDF81FFFF},
{0xDF900000,0xDFA3FFFF},
{0xDFA60000,0xDFA7FFFF},
{0xDFC00000,0xDFC1FFFF},
{0xDFC60000,0xDFC7FFFF},
{0xDFC90000,0xDFCBFFFF},
{0xDFD00000,0xDFD7FFFF},
{0xDFDC0000,0xDFDDFFFF},
{0xDFDFB000,0xDFDFCFFF},
{0xDFF00000,0xDFFBFFFF},
{0xDFFC8000,0xDFFCFFFF},
{0xDFFE0000,0xDFFF7FFF},
{0xDFFFEC00,0xDFFFEFFF},
{0xDFFFFC00,0xDFFFFDFF},
};
